// degree-31.m /////////////////////////////////////////////////////////////////
// 
// Benjamin Smith
// INRIA Saclay--Île-de-France 2009
// 
// Contact: smith@lix.polytechnique.fr
//
// File last updated 15 June 2010
//
// This file is distributed with the article
// "Families of explicitly isogenous Jacobians of variable-separated curves"
//
// This file is an executable Magma program: see
//	http://magma.maths.usyd.edu.au/
// It contains a series of definitions, followed by a series of assertions
// to verify the correctness of the definitions.
// If the assertions are correct, then no output is produced.
// If the assertions no not hold, then executing this file will produce a
// runtime error.
// 
// We define:
//	k_0	: A totally real cubic number field
//     	k	: The base field (a quadratic imaginary extension of k_0)
//	alpha_31: A generator of k over k_0
//	sigma	: An automorphism of k over k_0,
//		  corresponding to complex conjugation 
//     	f_31	: A univariate polynomial over k 
//	g_31	: A univariate polynomial over k
//	A_31	: A bivariate polynomial over k
//	B_31	: A bivariate polynomial over k
//	M_30	: A 30x30 matrix over k
//
// The file concludes with an assertion: 
//	f_31(x_1) - g_31(x_2) = A_31(x_1,x_2)B_31(x_1,x_2).
// 
// Briefly, the correspondence V(y_1 - y_2, A_31(x_1,x_2))
// induces an isogeny between the Jacobians of the curves
//     X: P_d(y_1) = f_31(x_1)   and   Y: P_d(y_2) = g_31(x_2) 
// where P_d is the generic monic polynomial of degree d.
//
// The isogeny splits multiplication-by-8 .
//
// The regular differentials on X (resp. Y) 
// have bases of the form 
//      w_{i,j} = y_1^{i-1}d(x_1^j)/P_d'(y_1)   (on X)
// and
//      w_{i,j}' = y_2^{i-1}d(x_2^j)/P_d'(y_2)  (on Y),
// where (i,j) ranges over the interior integer points of the Newton polygon
// of X and Y, which is { (x,y) in RR^2 : x >= 0, y >= 0, dx + 31y <= 31d }.
//
// The homomorphism of regular differentials induced by the isogeny
// is given by the diagonal block matrix \oplus_i M_j ,
// where M_j is the upper-left jxj submatrix of M_30.
//
// We note that f_31(x) = 2^31g(x/2), where g is the polynomial in \S5.6
// of Cassou-Nogues and Couveignes, "Factorisations explicites de g(y)-h(z)".

// To navigate through this file, use the following tags:
//	BASEFIELD	: Section defining base field and sigma
//	POLYNOMIALS	: Section defining f_31 and g_31
//	FACTORS		: Section defining A_31 and B_31
//	MATRIX		: Section defining M_30
//	ASSERTIONS	: Section containing assertions

// Section BASEFIELD ///////////////////////////////////////////////////////////

k_0 := ext< Rationals( ) | Polynomial([ -32, 46, -13, 1 ]) > ;
beta_31 := k_0.1;
k := ext< k_0 | Polynomial([ beta_31, 1/2*(-beta_31^2 + 7*beta_31 - 4), 1 ]) > ;
alpha_31 := k.1;

sigma := hom< k -> k | Norm(alpha_31)/alpha_31 >;

// Section POLYNOMIALS /////////////////////////////////////////////////////////

f_31 := Polynomial( [
  1/2*(40000652557427297213*beta_31^2 - 228111215551457603817*beta_31 + 
    175369855678896275462)*alpha_31 - 65947328732694035550*beta_31 + 
    51893352350533476674,
  1/4*(189070484301308140439*beta_31^2 - 1078181713565041645659*beta_31 + 
    828755544392518284178)*alpha_31 - 46180860191685737818*beta_31^2 + 
    263330622735026568546*beta_31 - 202353488482863505116,
  (54463036894808302775*beta_31^2 - 310565247955444662791*beta_31 + 
    238667906914571238966)*alpha_31 - 81576545272770042846*beta_31^2 + 
    465175491155452302090*beta_31 - 357527735296323255856,
  1/4*(169218296815772037563*beta_31^2 - 964871825432269155259*beta_31 + 
    741281753605109330158)*alpha_31 + 1/2*(-170893733526743164527*beta_31^2 + 
    974524478702120706149*beta_31 - 749110876332923424056),
  1/2*(49304582752543946067*beta_31^2 - 281098867828603968415*beta_31 + 
    215847048521953856642)*alpha_31 - 61963733150285996210*beta_31^2 + 
    353359956339248549630*beta_31 - 271645099064981266264,
  1/4*(45306320007972580007*beta_31^2 - 258259115732840763971*beta_31 + 
    198131731784385144890)*alpha_31 - 35113437757521647733*beta_31^2 + 
    200245081834733083523*beta_31 - 153945968219252375932,
  (4289330197341614122*beta_31^2 - 24444482559724768306*beta_31 + 
    18725730521027593468)*alpha_31 - 16452200924663428476*beta_31^2 + 
    93824570890267314132*beta_31 - 72138410012520487392,
  1/4*(5349022339561158889*beta_31^2 - 30468310565663764701*beta_31 + 
    23269831385235635478)*alpha_31 + 1/2*(-12981826330621135479*beta_31^2 + 
    74033411414487355933*beta_31 - 56931350500304786584),
  1/2*(666741406316608901*beta_31^2 - 3793174348260871249*beta_31 + 
    2877699891087105974)*alpha_31 - 2228257638211545416*beta_31^2 + 
    12707540317242003664*beta_31 - 9774630622222967016,
  1/4*(252759275517997259*beta_31^2 - 1433030325295209471*beta_31 + 
    1068435495227581290)*alpha_31 - 674737244001767348*beta_31^2 + 
    3848397762327800800*beta_31 - 2961837259209390796,
  (5114882992266101*beta_31^2 - 28258439276473693*beta_31 + 
    18341300244745514)*alpha_31 - 179038726833672882*beta_31^2 + 
    1021502208629970342*beta_31 - 787043118448073168,
  1/4*(-8586321824356509*beta_31^2 + 50257973052534709*beta_31 - 
    43387678241376842)*alpha_31 + 1/2*(-85449770728926123*beta_31^2 + 
    487803728937129657*beta_31 - 376505500218991832),
  1/2*(-2622447102965197*beta_31^2 + 15140814106353601*beta_31 - 
    12381797317084030)*alpha_31 - 8987190683152838*beta_31^2 + 
    51343013421092666*beta_31 - 39775561327583640,
  1/4*(-1978230166415349*beta_31^2 + 11377218629025417*beta_31 - 
    9187472935957486)*alpha_31 - 1624443945300571*beta_31^2 + 
    9288098757775717*beta_31 - 7247838137686636,
  (-139018382734952*beta_31^2 + 798155715081992*beta_31 - 
    639885918228208)*alpha_31 - 261142058999232*beta_31^2 + 
    1495093982891056*beta_31 - 1182442479204304,
  1/2*(-68634980704065*beta_31^2 + 394204332490837*beta_31 - 
    314837295570662)*alpha_31 - 29763143643412*beta_31^2 + 
    171589237835129*beta_31 - 142017002199943,
  1/2*(-15318617080201*beta_31^2 + 88038399797701*beta_31 - 
    69943216106158)*alpha_31 - 1895795391860*beta_31^2 + 11416737130644*beta_31 
    - 11352444092264,
  1/4*(-5769455583795*beta_31^2 + 33098655938119*beta_31 - 
    25835400965402)*alpha_31 + 294028221850*beta_31^2 - 1473933339994*beta_31 + 
    518844517892,
  (-269614339219*beta_31^2 + 1542675899235*beta_31 - 1188295598542)*alpha_31 + 
    183245379494*beta_31^2 - 993087450674*beta_31 + 623917502240,
  1/4*(-163995728955*beta_31^2 + 924422399803*beta_31 - 677387480302)*alpha_31 +
    1/2*(78169232743*beta_31^2 - 433339194421*beta_31 + 287510233584),
  1/2*(-11930510983*beta_31^2 + 65478094755*beta_31 - 43673976698)*alpha_31 + 
    9528517306*beta_31^2 - 54008839654*beta_31 + 37472520008,
  1/4*(-3393920083*beta_31^2 + 18486225567*beta_31 - 11435436674)*alpha_31 + 
    1443863905*beta_31^2 - 8223169647*beta_31 + 5805567284,
  (-91211858*beta_31^2 + 479106426*beta_31 - 169731820)*alpha_31 + 
    218157788*beta_31^2 - 1246315940*beta_31 + 931639280,
  1/4*(-55060991*beta_31^2 + 290582251*beta_31 - 102066074)*alpha_31 + 
    1/2*(63289693*beta_31^2 - 358191267*beta_31 + 266981300),
  1/2*(-1504089*beta_31^2 + 6339221*beta_31 + 5726258)*alpha_31 + 
    2485704*beta_31^2 - 13721344*beta_31 + 12499448,
  1/4*(-543151*beta_31^2 + 2309779*beta_31 + 1873950)*alpha_31 + 
    436852*beta_31^2 - 2395432*beta_31 + 2119780,
  (1271*beta_31^2 - 30287*beta_31 + 86862)*alpha_31 + 27466*beta_31^2 - 
    185566*beta_31 + 201376,
  1/4*(1333*beta_31^2 - 31341*beta_31 + 88474)*alpha_31 + 1/2*(14043*beta_31^2 -
    94705*beta_31 + 100688),
  1/2*(-31*beta_31^2 + 155*beta_31 + 310)*alpha_31 + 62*beta_31^2 - 434*beta_31 
    + 744,
  1/4*(-31*beta_31^2 + 155*beta_31 + 310)*alpha_31 + 31*beta_31^2 - 217*beta_31 
    + 372,
  0,
  1
]);

g_31 := Polynomial([sigma(c): c in Coefficients(f_31) ]);


// Section FACTORS /////////////////////////////////////////////////////////////

R<x_1,x_2> := PolynomialRing(k,2);

A_31 :=
x_1^15 + (1/4*(beta_31^2 - 9*beta_31 + 14)*alpha_31 - beta_31 + 4)*x_1^14*x_2 + 
  (1/2*(beta_31^2 - 10*beta_31 + 18)*alpha_31 + 1/2*(2*beta_31^2 - 17*beta_31 + 
  24))*x_1^13*x_2^2 + (1/4*(-15*beta_31^2 + 75*beta_31 + 150)*alpha_31 + 
  (15*beta_31^2 - 113*beta_31 + 204))*x_1^13 + (1/4*(3*beta_31^2 - 29*beta_31 + 
  54)*alpha_31 + 1/2*(3*beta_31^2 - 26*beta_31 + 32))*x_1^12*x_2^3 + 
  (1/2*(beta_31^2 - 45*beta_31 + 526)*alpha_31 - 50*beta_31^2 + 298*beta_31 + 
  20)*x_1^12*x_2 + (1/2*(-19*beta_31^2 + 127*beta_31 + 30)*alpha_31 + 
  (26*beta_31^2 - 174*beta_31 + 320))*x_1^12 + (1/2*(beta_31^2 - 11*beta_31 + 
  28)*alpha_31 + (beta_31^2 - 10*beta_31 + 14))*x_1^11*x_2^4 + 
  (1/2*(-21*beta_31^2 - 35*beta_31 + 1046)*alpha_31 - 33*beta_31^2 + 259*beta_31
  + 128)*x_1^11*x_2^2 + ((-beta_31^2 - 19*beta_31 + 402)*alpha_31 - 
  128*beta_31^2 + 768*beta_31 - 128)*x_1^11*x_2 + (1/4*(765*beta_31^2 - 
  10581*beta_31 + 24522)*alpha_31 + 1/2*(2355*beta_31^2 - 17297*beta_31 + 
  22040))*x_1^11 + ((-2*beta_31 + 13)*alpha_31 + (beta_31^2 - 8*beta_31 + 
  12))*x_1^10*x_2^5 + ((23*beta_31^2 - 293*beta_31 + 912)*alpha_31 - 
  24*beta_31^2 + 220*beta_31 + 132)*x_1^10*x_2^3 + ((-17*beta_31^2 - 59*beta_31 
  + 954)*alpha_31 + (6*beta_31^2 + 70*beta_31 + 568))*x_1^10*x_2^2 + 
  (1/4*(5649*beta_31^2 - 47161*beta_31 + 81026)*alpha_31 + (409*beta_31^2 - 
  7263*beta_31 + 12556))*x_1^10*x_2 + ((545*beta_31^2 - 7925*beta_31 + 
  18150)*alpha_31 + (5670*beta_31^2 - 39858*beta_31 + 46368))*x_1^10 + 
  (1/2*(-3*beta_31 + 26)*alpha_31 + 1/2*(-beta_31^2 + 6*beta_31 + 
  4))*x_1^9*x_2^6 + (1/2*(143*beta_31^2 - 1339*beta_31 + 2650)*alpha_31 - 
  58*beta_31^2 + 290*beta_31 + 84)*x_1^9*x_2^4 + ((68*beta_31^2 - 692*beta_31 + 
  1720)*alpha_31 - 76*beta_31^2 + 540*beta_31 + 88)*x_1^9*x_2^3 + 
  ((343*beta_31^2 - 6534*beta_31 + 23107)*alpha_31 + 1/2*(2595*beta_31^2 - 
  25293*beta_31 + 34332))*x_1^9*x_2^2 + ((5113*beta_31^2 - 40885*beta_31 + 
  69518)*alpha_31 - 3620*beta_31^2 + 3476*beta_31 + 27080)*x_1^9*x_2 + 
  (1/4*(-25099*beta_31^2 + 60031*beta_31 + 392278)*alpha_31 + (13240*beta_31^2 -
  71732*beta_31 + 116836))*x_1^9 + (1/4*(-beta_31^2 + beta_31 + 42)*alpha_31 - 
  beta_31^2 + 7*beta_31 - 2)*x_1^8*x_2^7 + (1/2*(101*beta_31^2 - 1185*beta_31 + 
  2598)*alpha_31 + (77*beta_31^2 - 593*beta_31 + 734))*x_1^8*x_2^5 + 
  ((100*beta_31^2 - 1004*beta_31 + 2048)*alpha_31 - 102*beta_31^2 + 494*beta_31 
  + 108)*x_1^8*x_2^4 + ((-430*beta_31^2 - 1054*beta_31 + 21528)*alpha_31 + 
  (2915*beta_31^2 - 18639*beta_31 + 19586))*x_1^8*x_2^3 + ((-1184*beta_31^2 - 
  8740*beta_31 + 72012)*alpha_31 + (10130*beta_31^2 - 74654*beta_31 + 
  89432))*x_1^8*x_2^2 + (1/2*(52463*beta_31^2 - 414227*beta_31 + 
  759074)*alpha_31 - 24207*beta_31^2 + 152891*beta_31 - 60538)*x_1^8*x_2 + 
  (1/2*(-83851*beta_31^2 + 284415*beta_31 + 782422)*alpha_31 + (124550*beta_31^2
  - 697110*beta_31 + 892204))*x_1^8 + (1/4*(-beta_31^2 + beta_31 + 42)*alpha_31 
  + 1/2*(-beta_31^2 + 9*beta_31 + 2))*x_1^7*x_2^8 + ((79*beta_31^2 - 743*beta_31
  + 1374)*alpha_31 + (90*beta_31^2 - 726*beta_31 + 856))*x_1^7*x_2^6 + 
  ((98*beta_31^2 - 1082*beta_31 + 2204)*alpha_31 + (240*beta_31^2 - 1696*beta_31
  + 1904))*x_1^7*x_2^5 + (1/2*(1907*beta_31^2 - 16299*beta_31 + 55110)*alpha_31 
  - 2782*beta_31^2 + 17470*beta_31 - 8972)*x_1^7*x_2^4 + ((1146*beta_31^2 - 
  18802*beta_31 + 87020)*alpha_31 + (7448*beta_31^2 - 48888*beta_31 + 
  62352))*x_1^7*x_2^3 + ((21735*beta_31^2 - 224267*beta_31 + 486354)*alpha_31 - 
  31664*beta_31^2 + 165096*beta_31 - 81928)*x_1^7*x_2^2 + ((192618*beta_31^2 - 
  1399074*beta_31 + 2176140)*alpha_31 - 256064*beta_31^2 + 1465840*beta_31 - 
  674448)*x_1^7*x_2 + (1/4*(-504267*beta_31^2 + 1221271*beta_31 + 
  5822030)*alpha_31 + 1/2*(895805*beta_31^2 - 5502111*beta_31 + 5411720))*x_1^7 
  + (1/2*(-3*beta_31 + 26)*alpha_31 + 1/2*(-3*beta_31^2 + 22*beta_31 - 
  8))*x_1^6*x_2^9 + ((79*beta_31^2 - 743*beta_31 + 1374)*alpha_31 + 
  (30*beta_31^2 - 430*beta_31 + 700))*x_1^6*x_2^7 + ((180*beta_31^2 - 
  1588*beta_31 + 2696)*alpha_31 + (88*beta_31^2 - 976*beta_31 + 
  1368))*x_1^6*x_2^6 + (1/2*(-1623*beta_31^2 + 4159*beta_31 + 36930)*alpha_31 - 
  2320*beta_31^2 + 15592*beta_31 - 6568)*x_1^6*x_2^5 + ((3050*beta_31^2 - 
  28066*beta_31 + 98956)*alpha_31 - 16216*beta_31^2 + 95304*beta_31 - 
  47168)*x_1^6*x_2^4 + ((955*beta_31^2 - 115559*beta_31 + 403890)*alpha_31 + 
  (62584*beta_31^2 - 403608*beta_31 + 336912))*x_1^6*x_2^3 + ((19550*beta_31^2 -
  611318*beta_31 + 2047028)*alpha_31 - 84296*beta_31^2 + 350776*beta_31 + 
  179808)*x_1^6*x_2^2 + (1/4*(1534243*beta_31^2 - 11133663*beta_31 + 
  20090354)*alpha_31 - 337507*beta_31^2 + 1971749*beta_31 - 1081700)*x_1^6*x_2 +
  ((-998614*beta_31^2 + 3676542*beta_31 + 5450220)*alpha_31 + (2666468*beta_31^2
  - 16726812*beta_31 + 16035216))*x_1^6 + ((-2*beta_31 + 13)*alpha_31 + 
  1/2*(-3*beta_31^2 + 23*beta_31 - 12))*x_1^5*x_2^10 + (1/2*(101*beta_31^2 - 
  1185*beta_31 + 2598)*alpha_31 + (142*beta_31^2 - 1142*beta_31 + 
  1300))*x_1^5*x_2^8 + ((98*beta_31^2 - 1082*beta_31 + 2204)*alpha_31 + 
  (140*beta_31^2 - 1356*beta_31 + 1592))*x_1^5*x_2^7 + (1/2*(-1623*beta_31^2 + 
  4159*beta_31 + 36930)*alpha_31 + (1456*beta_31^2 - 6298*beta_31 + 
  14270))*x_1^5*x_2^6 + ((-6196*beta_31^2 + 25124*beta_31 + 59304)*alpha_31 + 
  (3252*beta_31^2 - 10372*beta_31 + 37112))*x_1^5*x_2^5 + (1/2*(74357*beta_31^2 
  - 616345*beta_31 + 1047966)*alpha_31 + (40088*beta_31^2 - 289880*beta_31 + 
  296496))*x_1^5*x_2^4 + ((23174*beta_31^2 - 705070*beta_31 + 2189812)*alpha_31 
  + (565304*beta_31^2 - 3538088*beta_31 + 3232640))*x_1^5*x_2^3 + 
  (1/2*(98783*beta_31^2 - 2168235*beta_31 + 8977658)*alpha_31 - 313580*beta_31^2
  + 2041112*beta_31 - 1357820)*x_1^5*x_2^2 + ((2128198*beta_31^2 - 
  14341774*beta_31 + 23754836)*alpha_31 + (447344*beta_31^2 - 2607568*beta_31 + 
  4437376))*x_1^5*x_2 + (1/4*(-12883637*beta_31^2 + 54258761*beta_31 + 
  35971986)*alpha_31 + (8740911*beta_31^2 - 51851881*beta_31 + 45168324))*x_1^5 
  + (1/2*(beta_31^2 - 11*beta_31 + 28)*alpha_31 + 1/2*(-beta_31^2 + 9*beta_31 - 
  4))*x_1^4*x_2^11 + (1/2*(143*beta_31^2 - 1339*beta_31 + 2650)*alpha_31 + 
  (117*beta_31^2 - 989*beta_31 + 1114))*x_1^4*x_2^9 + ((100*beta_31^2 - 
  1004*beta_31 + 2048)*alpha_31 + (290*beta_31^2 - 2210*beta_31 + 
  2260))*x_1^4*x_2^8 + (1/2*(1907*beta_31^2 - 16299*beta_31 + 55110)*alpha_31 - 
  3710*beta_31^2 + 24160*beta_31 - 7282)*x_1^4*x_2^7 + ((3050*beta_31^2 - 
  28066*beta_31 + 98956)*alpha_31 - 3964*beta_31^2 + 33756*beta_31 + 
  5512)*x_1^4*x_2^6 + (1/2*(74357*beta_31^2 - 616345*beta_31 + 1047966)*alpha_31
  - 46775*beta_31^2 + 187975*beta_31 + 17162)*x_1^4*x_2^5 + ((354046*beta_31^2 -
  2614102*beta_31 + 3738804)*alpha_31 - 199962*beta_31^2 + 691642*beta_31 + 
  179804)*x_1^4*x_2^4 + (1/4*(254883*beta_31^2 - 4767403*beta_31 + 
  16914582)*alpha_31 + 1/2*(-183305*beta_31^2 + 888795*beta_31 + 
  626608))*x_1^4*x_2^3 + ((1085952*beta_31^2 - 8952408*beta_31 + 
  23139464)*alpha_31 - 7863460*beta_31^2 + 45704364*beta_31 - 
  31773824)*x_1^4*x_2^2 + (1/2*(16206565*beta_31^2 - 105899009*beta_31 + 
  141990246)*alpha_31 - 6383318*beta_31^2 + 34704150*beta_31 - 
  20708444)*x_1^4*x_2 + (1/2*(-17722181*beta_31^2 + 68257849*beta_31 + 
  66102226)*alpha_31 + (8191474*beta_31^2 - 47885958*beta_31 + 42466608))*x_1^4 
  + (1/4*(3*beta_31^2 - 29*beta_31 + 54)*alpha_31 + 1/2*(-beta_31 + 
  2))*x_1^3*x_2^12 + ((23*beta_31^2 - 293*beta_31 + 912)*alpha_31 + 
  (33*beta_31^2 - 375*beta_31 + 524))*x_1^3*x_2^10 + ((68*beta_31^2 - 
  692*beta_31 + 1720)*alpha_31 + (68*beta_31^2 - 756*beta_31 + 
  1016))*x_1^3*x_2^9 + ((-430*beta_31^2 - 1054*beta_31 + 21528)*alpha_31 - 
  2777*beta_31^2 + 19393*beta_31 - 4498)*x_1^3*x_2^8 + ((1146*beta_31^2 - 
  18802*beta_31 + 87020)*alpha_31 - 15180*beta_31^2 + 98428*beta_31 - 
  45576)*x_1^3*x_2^7 + ((955*beta_31^2 - 115559*beta_31 + 403890)*alpha_31 + 
  (64958*beta_31^2 - 493006*beta_31 + 612572))*x_1^3*x_2^6 + ((23174*beta_31^2 -
  705070*beta_31 + 2189812)*alpha_31 + (37868*beta_31^2 - 776812*beta_31 + 
  1444152))*x_1^3*x_2^5 + (1/4*(254883*beta_31^2 - 4767403*beta_31 + 
  16914582)*alpha_31 + 1/2*(811817*beta_31^2 - 5798145*beta_31 + 
  8363650))*x_1^3*x_2^4 + ((-3163452*beta_31^2 + 15416844*beta_31 + 
  4279224)*alpha_31 + (4275996*beta_31^2 - 23605068*beta_31 + 
  24231720))*x_1^3*x_2^3 + (1/2*(-5126819*beta_31^2 + 15923271*beta_31 + 
  56736470)*alpha_31 - 6303008*beta_31^2 + 36190280*beta_31 - 
  19853624)*x_1^3*x_2^2 + ((8668579*beta_31^2 - 72646983*beta_31 + 
  131804458)*alpha_31 + (38707416*beta_31^2 - 231317256*beta_31 + 
  192902912))*x_1^3*x_2 + (1/4*(-158657181*beta_31^2 + 746617533*beta_31 + 
  4292638)*alpha_31 + 1/2*(119634177*beta_31^2 - 697080331*beta_31 + 
  588501032))*x_1^3 + (1/2*(beta_31^2 - 10*beta_31 + 18)*alpha_31 + 
  1/2*(beta_31^2 - 8*beta_31 + 4))*x_1^2*x_2^13 + (1/2*(-21*beta_31^2 - 
  35*beta_31 + 1046)*alpha_31 + (13*beta_31^2 - 77*beta_31 + 114))*x_1^2*x_2^11 
  + ((-17*beta_31^2 - 59*beta_31 + 954)*alpha_31 - 44*beta_31 + 
  100)*x_1^2*x_2^10 + ((343*beta_31^2 - 6534*beta_31 + 23107)*alpha_31 + 
  (577*beta_31^2 - 1847*beta_31 + 8236))*x_1^2*x_2^9 + ((-1184*beta_31^2 - 
  8740*beta_31 + 72012)*alpha_31 + (1396*beta_31^2 - 1292*beta_31 + 
  20048))*x_1^2*x_2^8 + ((21735*beta_31^2 - 224267*beta_31 + 486354)*alpha_31 + 
  (70058*beta_31^2 - 520794*beta_31 + 610932))*x_1^2*x_2^7 + ((19550*beta_31^2 -
  611318*beta_31 + 2047028)*alpha_31 + (542836*beta_31^2 - 3638756*beta_31 + 
  3630424))*x_1^2*x_2^6 + (1/2*(98783*beta_31^2 - 2168235*beta_31 + 
  8977658)*alpha_31 + (432471*beta_31^2 - 3070915*beta_31 + 
  4984458))*x_1^2*x_2^5 + ((1085952*beta_31^2 - 8952408*beta_31 + 
  23139464)*alpha_31 + (3603816*beta_31^2 - 20230664*beta_31 + 
  24482032))*x_1^2*x_2^4 + (1/2*(-5126819*beta_31^2 + 15923271*beta_31 + 
  56736470)*alpha_31 + (14375355*beta_31^2 - 82443071*beta_31 + 
  81818298))*x_1^2*x_2^3 + ((19739410*beta_31^2 - 138521290*beta_31 + 
  198250268)*alpha_31 - 19435322*beta_31^2 + 96568434*beta_31 - 
  37571628)*x_1^2*x_2^2 + (1/4*(221072025*beta_31^2 - 1475642965*beta_31 + 
  1860232654)*alpha_31 + (88210042*beta_31^2 - 530277906*beta_31 + 
  469132748))*x_1^2*x_2 + ((-48643205*beta_31^2 + 223406661*beta_31 + 
  55453486)*alpha_31 + (84469314*beta_31^2 - 486919702*beta_31 + 
  401866768))*x_1^2 + (1/4*(beta_31^2 - 9*beta_31 + 14)*alpha_31 + 
  1/2*(beta_31^2 - 7*beta_31 + 2))*x_1*x_2^14 + (1/2*(beta_31^2 - 45*beta_31 + 
  526)*alpha_31 - 23*beta_31^2 + 211*beta_31 - 234)*x_1*x_2^12 + ((-beta_31^2 - 
  19*beta_31 + 402)*alpha_31 + (2*beta_31^2 + 118*beta_31 - 276))*x_1*x_2^11 + 
  (1/4*(5649*beta_31^2 - 47161*beta_31 + 81026)*alpha_31 - 587*beta_31^2 + 
  2860*beta_31 - 1)*x_1*x_2^10 + ((5113*beta_31^2 - 40885*beta_31 + 
  69518)*alpha_31 - 518*beta_31^2 + 5038*beta_31 - 2804)*x_1*x_2^9 + 
  (1/2*(52463*beta_31^2 - 414227*beta_31 + 759074)*alpha_31 - 16388*beta_31^2 + 
  26348*beta_31 + 97056)*x_1*x_2^8 + ((192618*beta_31^2 - 1399074*beta_31 + 
  2176140)*alpha_31 - 101908*beta_31^2 + 269492*beta_31 + 216024)*x_1*x_2^7 + 
  (1/4*(1534243*beta_31^2 - 11133663*beta_31 + 20090354)*alpha_31 + 
  1/2*(-1455267*beta_31^2 + 7899983*beta_31 - 2501314))*x_1*x_2^6 + 
  ((2128198*beta_31^2 - 14341774*beta_31 + 23754836)*alpha_31 - 
  7607004*beta_31^2 + 44212396*beta_31 - 26785672)*x_1*x_2^5 + 
  (1/2*(16206565*beta_31^2 - 105899009*beta_31 + 141990246)*alpha_31 - 
  16124815*beta_31^2 + 90439651*beta_31 - 52004850)*x_1*x_2^4 + 
  ((8668579*beta_31^2 - 72646983*beta_31 + 131804458)*alpha_31 - 
  42703118*beta_31^2 + 224612854*beta_31 - 126343684)*x_1*x_2^3 + 
  (1/4*(221072025*beta_31^2 - 1475642965*beta_31 + 1860232654)*alpha_31 + 
  1/2*(-417662025*beta_31^2 + 2307105349*beta_31 - 1604811630))*x_1*x_2^2 + 
  ((85305102*beta_31^2 - 551201430*beta_31 + 700327908)*alpha_31 - 
  116025750*beta_31^2 + 641570046*beta_31 - 385361364)*x_1*x_2 + 
  (1/4*(-218115749*beta_31^2 + 878033009*beta_31 + 974379018)*alpha_31 - 
  129060140*beta_31^2 + 741082668*beta_31 - 540163384)*x_1 - x_2^15 + 
  (1/4*(-15*beta_31^2 + 75*beta_31 + 150)*alpha_31 + 1/2*(-45*beta_31^2 + 
  361*beta_31 - 438))*x_2^13 + (1/2*(-19*beta_31^2 + 127*beta_31 + 30)*alpha_31 
  - 53*beta_31^2 + 401*beta_31 - 454)*x_2^12 + (1/4*(765*beta_31^2 - 
  10581*beta_31 + 24522)*alpha_31 + 1/2*(501*beta_31^2 - 4225*beta_31 + 
  1366))*x_2^11 + ((545*beta_31^2 - 7925*beta_31 + 18150)*alpha_31 - 
  780*beta_31^2 + 3448*beta_31 - 8188)*x_2^10 + (1/4*(-25099*beta_31^2 + 
  60031*beta_31 + 392278)*alpha_31 + 1/2*(11295*beta_31^2 - 70763*beta_31 + 
  98554))*x_2^9 + (1/2*(-83851*beta_31^2 + 284415*beta_31 + 782422)*alpha_31 + 
  (7881*beta_31^2 - 62205*beta_31 + 74902))*x_2^8 + (1/4*(-504267*beta_31^2 + 
  1221271*beta_31 + 5822030)*alpha_31 + (177592*beta_31^2 - 1123139*beta_31 + 
  1600449))*x_2^7 + ((-998614*beta_31^2 + 3676542*beta_31 + 5450220)*alpha_31 + 
  (1553848*beta_31^2 - 8820944*beta_31 + 10106616))*x_2^6 + 
  (1/4*(-12883637*beta_31^2 + 54258761*beta_31 + 35971986)*alpha_31 + 
  1/2*(8089773*beta_31^2 - 49530129*beta_31 + 58035854))*x_2^5 + 
  (1/2*(-17722181*beta_31^2 + 68257849*beta_31 + 66102226)*alpha_31 + 
  (32395825*beta_31^2 - 200780773*beta_31 + 196033062))*x_2^4 + 
  (1/4*(-158657181*beta_31^2 + 746617533*beta_31 + 4292638)*alpha_31 + 
  1/2*(187280993*beta_31^2 - 1134011497*beta_31 + 1049810754))*x_2^3 + 
  ((-48643205*beta_31^2 + 223406661*beta_31 + 55453486)*alpha_31 + 
  (93161650*beta_31^2 - 561924226*beta_31 + 582467364))*x_2^2 + 
  (1/4*(-218115749*beta_31^2 + 878033009*beta_31 + 974379018)*alpha_31 + 
  1/2*(660517753*beta_31^2 - 3862716149*beta_31 + 3551239630))*x_2 + 
  (-114910051*beta_31^2 + 529266103*beta_31 + 96153158)*alpha_31 + 
  216253015*beta_31^2 - 1283951003*beta_31 + 1185400466
;

B_31 := 
x_1^16 + (1/4*(-beta_31^2 + 9*beta_31 - 14)*alpha_31 + (beta_31 - 4))*x_1^15*x_2
  + (1/4*(beta_31^2 - 11*beta_31 + 22)*alpha_31 + 1/2*(2*beta_31^2 - 15*beta_31 
  + 16))*x_1^14*x_2^2 + ((-4*beta_31^2 + 20*beta_31 + 40)*alpha_31 + 
  (16*beta_31^2 - 104*beta_31 + 168))*x_1^14 + (1/2*(-beta_31 + 2)*alpha_31 + 
  1/2*(beta_31^2 - 6*beta_31 + 8))*x_1^13*x_2^3 + (1/4*(-19*beta_31^2 + 
  183*beta_31 - 970)*alpha_31 + (70*beta_31^2 - 434*beta_31 + 176))*x_1^13*x_2 +
  ((-6*beta_31^2 + 14*beta_31 + 140)*alpha_31 + (36*beta_31^2 - 260*beta_31 + 
  424))*x_1^13 + (1/4*(-3*beta_31^2 + 25*beta_31 - 38)*alpha_31 + 1/2*(3*beta_31
  - 4))*x_1^12*x_2^4 + (1/2*(-33*beta_31^2 + 101*beta_31 + 266)*alpha_31 + 
  (54*beta_31^2 - 242*beta_31 + 176))*x_1^12*x_2^2 + (1/2*(-31*beta_31^2 + 
  339*beta_31 - 1458)*alpha_31 + (104*beta_31^2 - 592*beta_31 + 8))*x_1^12*x_2 +
  ((-48*beta_31^2 - 848*beta_31 + 3744)*alpha_31 + (2092*beta_31^2 - 
  13272*beta_31 + 12028))*x_1^12 + ((-beta_31 + 3)*alpha_31 + (beta_31^2 - 
  7*beta_31 + 4))*x_1^11*x_2^5 + (1/2*(-111*beta_31^2 + 679*beta_31 - 
  286)*alpha_31 + (60*beta_31^2 - 288*beta_31 + 324))*x_1^11*x_2^3 + 
  ((-33*beta_31^2 + 73*beta_31 + 542)*alpha_31 + (68*beta_31^2 - 260*beta_31 + 
  296))*x_1^11*x_2^2 + (1/4*(-6119*beta_31^2 + 41407*beta_31 - 56366)*alpha_31 +
  (3072*beta_31^2 - 15460*beta_31 + 10860))*x_1^11*x_2 + ((-118*beta_31^2 - 
  4414*beta_31 + 18304)*alpha_31 + (6500*beta_31^2 - 42476*beta_31 + 
  43392))*x_1^11 + (-1/2*beta_31*alpha_31 + 1/2*(beta_31 - 4))*x_1^10*x_2^6 + 
  ((-40*beta_31^2 + 240*beta_31 - 360)*alpha_31 + (126*beta_31^2 - 870*beta_31 +
  740))*x_1^10*x_2^4 + ((-85*beta_31^2 + 513*beta_31 - 246)*alpha_31 + 
  (116*beta_31^2 - 644*beta_31 + 568))*x_1^10*x_2^3 + (1/4*(-11731*beta_31^2 + 
  71423*beta_31 - 51234)*alpha_31 + (5104*beta_31^2 - 27066*beta_31 + 
  17630))*x_1^10*x_2^2 + ((-6389*beta_31^2 + 47193*beta_31 - 72030)*alpha_31 + 
  (7856*beta_31^2 - 34104*beta_31 + 14072))*x_1^10*x_2 + ((-21358*beta_31^2 + 
  105206*beta_31 - 21412)*alpha_31 + (85908*beta_31^2 - 479852*beta_31 + 
  363856))*x_1^10 + (1/2*(-beta_31^2 + 7*beta_31 - 2)*alpha_31 - beta_31^2 + 
  7*beta_31 - 2)*x_1^9*x_2^7 + ((-27*beta_31^2 + 115*beta_31 - 70)*alpha_31 + 
  (3*beta_31^2 + 25*beta_31 - 102))*x_1^9*x_2^5 + ((-49*beta_31^2 + 285*beta_31 
  - 622)*alpha_31 + (174*beta_31^2 - 1302*beta_31 + 1444))*x_1^9*x_2^4 + 
  (1/2*(-5323*beta_31^2 + 26239*beta_31 - 12010)*alpha_31 + (6133*beta_31^2 - 
  39089*beta_31 + 31462))*x_1^9*x_2^3 + ((-8007*beta_31^2 + 43651*beta_31 - 
  16218)*alpha_31 + (15960*beta_31^2 - 90704*beta_31 + 61912))*x_1^9*x_2^2 + 
  (1/4*(-345621*beta_31^2 + 2139089*beta_31 - 1983270)*alpha_31 + 
  (151745*beta_31^2 - 856469*beta_31 + 708902))*x_1^9*x_2 + ((-105653*beta_31^2 
  + 523857*beta_31 - 49926)*alpha_31 + (312786*beta_31^2 - 1728538*beta_31 + 
  1355596))*x_1^9 + (-beta_31 - 1)*x_1^8*x_2^8 + ((-51*beta_31^2 + 355*beta_31 -
  270)*alpha_31 - 102*beta_31^2 + 746*beta_31 - 680)*x_1^8*x_2^6 + 
  ((-59*beta_31^2 + 311*beta_31 - 34)*alpha_31 - 112*beta_31^2 + 944*beta_31 - 
  1184)*x_1^8*x_2^5 + (1/2*(-5185*beta_31^2 + 27365*beta_31 - 22166)*alpha_31 + 
  (1430*beta_31^2 - 8414*beta_31 + 9076))*x_1^8*x_2^4 + ((-6836*beta_31^2 + 
  30132*beta_31 - 6536)*alpha_31 + (14600*beta_31^2 - 94152*beta_31 + 
  76176))*x_1^8*x_2^3 + ((-110740*beta_31^2 + 607424*beta_31 - 460684)*alpha_31 
  + (210626*beta_31^2 - 1259294*beta_31 + 927016))*x_1^8*x_2^2 + 
  (1/2*(-708705*beta_31^2 + 4385773*beta_31 - 4388622)*alpha_31 + 
  (602092*beta_31^2 - 3512940*beta_31 + 2903352))*x_1^8*x_2 + 
  ((-1081448*beta_31^2 + 6091048*beta_31 - 3890512)*alpha_31 + 
  (2755838*beta_31^2 - 15420668*beta_31 + 11483782))*x_1^8 + (1/2*(beta_31^2 - 
  7*beta_31 + 2)*alpha_31 - 2*beta_31 + 4)*x_1^7*x_2^9 + (-46*beta_31^2 + 
  110*beta_31 + 84)*x_1^7*x_2^7 + ((-84*beta_31^2 + 700*beta_31 - 992)*alpha_31 
  - 144*beta_31^2 + 920*beta_31 - 792)*x_1^7*x_2^6 + (1/2*(-5623*beta_31^2 + 
  37423*beta_31 - 33774)*alpha_31 - 5338*beta_31^2 + 34886*beta_31 - 
  27976)*x_1^7*x_2^5 + ((-8802*beta_31^2 + 54986*beta_31 - 58188)*alpha_31 - 
  5112*beta_31^2 + 34856*beta_31 - 9280)*x_1^7*x_2^4 + ((-118645*beta_31^2 + 
  655245*beta_31 - 495290)*alpha_31 + (34136*beta_31^2 - 170360*beta_31 + 
  82128))*x_1^7*x_2^3 + ((-434618*beta_31^2 + 2376818*beta_31 - 
  1848748)*alpha_31 + (596100*beta_31^2 - 3522220*beta_31 + 
  2442144))*x_1^7*x_2^2 + (1/4*(-9864379*beta_31^2 + 56584927*beta_31 - 
  47927450)*alpha_31 + (3526015*beta_31^2 - 21085353*beta_31 + 
  17341364))*x_1^7*x_2 + ((-5147092*beta_31^2 + 29143836*beta_31 - 
  20122144)*alpha_31 + (10617464*beta_31^2 - 59656872*beta_31 + 42922304))*x_1^7
  + (1/2*beta_31*alpha_31 + 1/2*(-3*beta_31^2 + 22*beta_31 - 20))*x_1^6*x_2^10 +
  ((51*beta_31^2 - 355*beta_31 + 270)*alpha_31 - 90*beta_31^2 + 458*beta_31 - 
  436)*x_1^6*x_2^8 + ((84*beta_31^2 - 700*beta_31 + 992)*alpha_31 - 52*beta_31^2
  - 60*beta_31 + 360)*x_1^6*x_2^7 + (-5990*beta_31^2 + 31716*beta_31 - 
  26390)*x_1^6*x_2^6 + ((-4908*beta_31^2 + 32716*beta_31 - 24088)*alpha_31 - 
  17876*beta_31^2 + 108324*beta_31 - 96440)*x_1^6*x_2^5 + ((-95645*beta_31^2 + 
  576997*beta_31 - 413402)*alpha_31 - 161612*beta_31^2 + 990140*beta_31 - 
  709576)*x_1^6*x_2^4 + ((-427086*beta_31^2 + 2400414*beta_31 - 
  1610044)*alpha_31 - 195888*beta_31^2 + 1365392*beta_31 - 1221888)*x_1^6*x_2^3 
  + (1/4*(-12390717*beta_31^2 + 69392841*beta_31 - 51769126)*alpha_31 + 
  1/2*(3389745*beta_31^2 - 18601763*beta_31 + 12980032))*x_1^6*x_2^2 + 
  ((-10210874*beta_31^2 + 57310658*beta_31 - 44823068)*alpha_31 + 
  (11213336*beta_31^2 - 67615560*beta_31 + 58336384))*x_1^6*x_2 + 
  ((-27124956*beta_31^2 + 152634716*beta_31 - 110170776)*alpha_31 + 
  (52720912*beta_31^2 - 301187544*beta_31 + 224799096))*x_1^6 + ((beta_31 - 
  3)*alpha_31 + 1/2*(-beta_31^2 + 7*beta_31 - 12))*x_1^5*x_2^11 + ((27*beta_31^2
  - 115*beta_31 + 70)*alpha_31 - 173*beta_31^2 + 1149*beta_31 - 994)*x_1^5*x_2^9
  + ((59*beta_31^2 - 311*beta_31 + 34)*alpha_31 - 258*beta_31^2 + 1730*beta_31 -
  1940)*x_1^5*x_2^8 + (1/2*(5623*beta_31^2 - 37423*beta_31 + 33774)*alpha_31 - 
  8254*beta_31^2 + 44052*beta_31 - 32270)*x_1^5*x_2^7 + ((4908*beta_31^2 - 
  32716*beta_31 + 24088)*alpha_31 - 20116*beta_31^2 + 104372*beta_31 - 
  92328)*x_1^5*x_2^6 + (-309665*beta_31^2 + 1706793*beta_31 - 
  1313346)*x_1^5*x_2^5 + ((-226241*beta_31^2 + 1394581*beta_31 - 
  1028134)*alpha_31 - 907350*beta_31^2 + 5200870*beta_31 - 3754572)*x_1^5*x_2^4 
  + ((-2418934*beta_31^2 + 14316843*beta_31 - 11142283)*alpha_31 + 
  1/2*(-9497083*beta_31^2 + 56668569*beta_31 - 45548712))*x_1^5*x_2^3 + 
  ((-12233426*beta_31^2 + 70515466*beta_31 - 55604764)*alpha_31 - 
  3567624*beta_31^2 + 23586040*beta_31 - 20617504)*x_1^5*x_2^2 + 
  (1/4*(-185935441*beta_31^2 + 1058602253*beta_31 - 839625982)*alpha_31 + 
  (11296406*beta_31^2 - 67475802*beta_31 + 64725160))*x_1^5*x_2 + 
  ((-113068646*beta_31^2 + 641198782*beta_31 - 492348868)*alpha_31 + 
  (157405748*beta_31^2 - 897541876*beta_31 + 655640008))*x_1^5 + 
  (1/4*(3*beta_31^2 - 25*beta_31 + 38)*alpha_31 + 1/2*(beta_31^2 - 10*beta_31 + 
  14))*x_1^4*x_2^12 + ((40*beta_31^2 - 240*beta_31 + 360)*alpha_31 - 
  54*beta_31^2 + 230*beta_31 + 20)*x_1^4*x_2^10 + ((49*beta_31^2 - 285*beta_31 +
  622)*alpha_31 - 164*beta_31^2 + 868*beta_31 + 56)*x_1^4*x_2^9 + 
  (1/2*(5185*beta_31^2 - 27365*beta_31 + 22166)*alpha_31 - 9729*beta_31^2 + 
  59329*beta_31 - 43050)*x_1^4*x_2^8 + ((8802*beta_31^2 - 54986*beta_31 + 
  58188)*alpha_31 - 27684*beta_31^2 + 157652*beta_31 - 90872)*x_1^4*x_2^7 + 
  ((95645*beta_31^2 - 576997*beta_31 + 413402)*alpha_31 - 358932*beta_31^2 + 
  1988800*beta_31 - 1486348)*x_1^4*x_2^6 + ((226241*beta_31^2 - 1394581*beta_31 
  + 1028134)*alpha_31 - 1310012*beta_31^2 + 7114540*beta_31 - 
  5216680)*x_1^4*x_2^5 + 1/2*(-15981127*beta_31^2 + 88702067*beta_31 - 
  64861482)*x_1^4*x_2^4 + ((-5405278*beta_31^2 + 32647942*beta_31 - 
  27402340)*alpha_31 - 27543628*beta_31^2 + 158349244*beta_31 - 
  123758280)*x_1^4*x_2^3 + (1/2*(-82212469*beta_31^2 + 478392465*beta_31 - 
  373997062)*alpha_31 - 59490192*beta_31^2 + 348408104*beta_31 - 
  271901160)*x_1^4*x_2^2 + (1/2*(-312951449*beta_31^2 + 1788643797*beta_31 - 
  1377636430)*alpha_31 - 75360264*beta_31^2 + 433668112*beta_31 - 
  288437736)*x_1^4*x_2 + ((-392645916*beta_31^2 + 2234185868*beta_31 - 
  1727979752)*alpha_31 + (408098052*beta_31^2 - 2311870672*beta_31 + 
  1687756492))*x_1^4 + (1/2*(beta_31 - 2)*alpha_31 + 1/2*(-beta_31^2 + 8*beta_31
  - 4))*x_1^3*x_2^13 + (1/2*(111*beta_31^2 - 679*beta_31 + 286)*alpha_31 + 
  (8*beta_31^2 - 146*beta_31 + 142))*x_1^3*x_2^11 + ((85*beta_31^2 - 513*beta_31
  + 246)*alpha_31 + (2*beta_31^2 - 186*beta_31 + 124))*x_1^3*x_2^10 + 
  (1/2*(5323*beta_31^2 - 26239*beta_31 + 12010)*alpha_31 - 5418*beta_31^2 + 
  31122*beta_31 - 26140)*x_1^3*x_2^9 + ((6836*beta_31^2 - 30132*beta_31 + 
  6536)*alpha_31 - 21320*beta_31^2 + 129944*beta_31 - 111040)*x_1^3*x_2^8 + 
  ((118645*beta_31^2 - 655245*beta_31 + 495290)*alpha_31 - 383384*beta_31^2 + 
  2277700*beta_31 - 1814452)*x_1^3*x_2^7 + ((427086*beta_31^2 - 2400414*beta_31 
  + 1610044)*alpha_31 - 1487216*beta_31^2 + 8696344*beta_31 - 
  7035608)*x_1^3*x_2^6 + ((2418934*beta_31^2 - 14316843*beta_31 + 
  11142283)*alpha_31 - 10909966*beta_31^2 + 61788520*beta_31 - 
  48207098)*x_1^3*x_2^5 + ((5405278*beta_31^2 - 32647942*beta_31 + 
  27402340)*alpha_31 - 40595976*beta_31^2 + 228094568*beta_31 - 
  175102576)*x_1^3*x_2^4 + (-168553318*beta_31^2 + 956908056*beta_31 - 
  743304178)*x_1^3*x_2^3 + ((-91107008*beta_31^2 + 525490116*beta_31 - 
  393882060)*alpha_31 - 414752490*beta_31^2 + 2373499258*beta_31 - 
  1837173396)*x_1^3*x_2^2 + (1/4*(-1582093529*beta_31^2 + 9057202841*beta_31 - 
  6837710234)*alpha_31 - 810595238*beta_31^2 + 4638515710*beta_31 - 
  3477021764)*x_1^3*x_2 + ((-1205989898*beta_31^2 + 6882210758*beta_31 - 
  5320863512)*alpha_31 + (439997196*beta_31^2 - 2446308212*beta_31 + 
  1720981168))*x_1^3 + (1/4*(-beta_31^2 + 11*beta_31 - 22)*alpha_31 + 
  1/2*(beta_31 - 2))*x_1^2*x_2^14 + (1/2*(33*beta_31^2 - 101*beta_31 - 
  266)*alpha_31 - 25*beta_31^2 + 245*beta_31 - 334)*x_1^2*x_2^12 + 
  ((33*beta_31^2 - 73*beta_31 - 542)*alpha_31 - 36*beta_31^2 + 336*beta_31 - 
  620)*x_1^2*x_2^11 + (1/4*(11731*beta_31^2 - 71423*beta_31 + 51234)*alpha_31 + 
  1/2*(-1045*beta_31^2 + 1177*beta_31 - 7678))*x_1^2*x_2^10 + ((8007*beta_31^2 -
  43651*beta_31 + 16218)*alpha_31 - 5322*beta_31^2 + 26242*beta_31 - 
  40780)*x_1^2*x_2^9 + ((110740*beta_31^2 - 607424*beta_31 + 460684)*alpha_31 - 
  190764*beta_31^2 + 1107476*beta_31 - 906608)*x_1^2*x_2^8 + ((434618*beta_31^2 
  - 2376818*beta_31 + 1848748)*alpha_31 - 1020944*beta_31^2 + 6058616*beta_31 - 
  4949592)*x_1^2*x_2^7 + (1/4*(12390717*beta_31^2 - 69392841*beta_31 + 
  51769126)*alpha_31 - 8489864*beta_31^2 + 49601557*beta_31 - 
  39200391)*x_1^2*x_2^6 + ((12233426*beta_31^2 - 70515466*beta_31 + 
  55604764)*alpha_31 - 40025276*beta_31^2 + 229855900*beta_31 - 
  177988472)*x_1^2*x_2^5 + (1/2*(82212469*beta_31^2 - 478392465*beta_31 + 
  373997062)*alpha_31 - 175312981*beta_31^2 + 994742689*beta_31 - 
  764957014)*x_1^2*x_2^4 + ((91107008*beta_31^2 - 525490116*beta_31 + 
  393882060)*alpha_31 - 675149316*beta_31^2 + 3831849008*beta_31 - 
  2963368428)*x_1^2*x_2^3 + 1/2*(-3333813479*beta_31^2 + 18956736515*beta_31 - 
  14592790842)*x_1^2*x_2^2 + ((-549863258*beta_31^2 + 3169512050*beta_31 - 
  2449174796)*alpha_31 - 3652979014*beta_31^2 + 20827659734*beta_31 - 
  15900518572)*x_1^2*x_2 + ((-2385691881*beta_31^2 + 13681247237*beta_31 - 
  10743012110)*alpha_31 - 1139873702*beta_31^2 + 6659604854*beta_31 - 
  5507878956)*x_1^2 + (1/4*(beta_31^2 - 9*beta_31 + 14)*alpha_31 + 
  1/2*(beta_31^2 - 7*beta_31 + 2))*x_1*x_2^15 + (1/4*(19*beta_31^2 - 183*beta_31
  + 970)*alpha_31 + 1/2*(beta_31^2 + 67*beta_31 - 66))*x_1*x_2^13 + 
  (1/2*(31*beta_31^2 - 339*beta_31 + 1458)*alpha_31 - 31*beta_31^2 + 291*beta_31
  - 226)*x_1*x_2^12 + (1/4*(6119*beta_31^2 - 41407*beta_31 + 56366)*alpha_31 - 
  454*beta_31^2 + 3103*beta_31 + 1449)*x_1*x_2^11 + ((6389*beta_31^2 - 
  47193*beta_31 + 72030)*alpha_31 - 1582*beta_31^2 + 6406*beta_31 + 
  11756)*x_1*x_2^10 + (1/4*(345621*beta_31^2 - 2139089*beta_31 + 
  1983270)*alpha_31 + 1/2*(-94283*beta_31^2 + 380231*beta_31 - 42562))*x_1*x_2^9
  + (1/2*(708705*beta_31^2 - 4385773*beta_31 + 4388622)*alpha_31 - 
  294749*beta_31^2 + 1347537*beta_31 - 416926)*x_1*x_2^8 + 
  (1/4*(9864379*beta_31^2 - 56584927*beta_31 + 47927450)*alpha_31 + 
  1/2*(-8831853*beta_31^2 + 49287717*beta_31 - 34055498))*x_1*x_2^7 + 
  ((10210874*beta_31^2 - 57310658*beta_31 + 44823068)*alpha_31 - 
  23061956*beta_31^2 + 131467988*beta_31 - 94583128)*x_1*x_2^6 + 
  (1/4*(185935441*beta_31^2 - 1058602253*beta_31 + 839625982)*alpha_31 + 
  1/2*(-272829273*beta_31^2 + 1561132109*beta_31 - 1166258806))*x_1*x_2^5 + 
  (1/2*(312951449*beta_31^2 - 1788643797*beta_31 + 1377636430)*alpha_31 - 
  553366717*beta_31^2 + 3153810385*beta_31 - 2378593342)*x_1*x_2^4 + 
  (1/4*(1582093529*beta_31^2 - 9057202841*beta_31 + 6837710234)*alpha_31 - 
  1991827767*beta_31^2 + 11325049884*beta_31 - 8637310213)*x_1*x_2^3 + 
  ((549863258*beta_31^2 - 3169512050*beta_31 + 2449174796)*alpha_31 - 
  5266568906*beta_31^2 + 29923335946*beta_31 - 22873548132)*x_1*x_2^2 + 
  1/2*(-21464223137*beta_31^2 + 122049020397*beta_31 - 92958742990)*x_1*x_2 + 
  (1/2*(-7712921793*beta_31^2 + 44286340893*beta_31 - 34927056958)*alpha_31 - 
  6948423847*beta_31^2 + 39746035739*beta_31 - 30841570114)*x_1 + x_2^16 + 
  ((4*beta_31^2 - 20*beta_31 - 40)*alpha_31 + (24*beta_31^2 - 176*beta_31 + 
  184))*x_2^14 + ((6*beta_31^2 - 14*beta_31 - 140)*alpha_31 + (40*beta_31^2 - 
  312*beta_31 + 352))*x_2^13 + ((48*beta_31^2 + 848*beta_31 - 3744)*alpha_31 + 
  (556*beta_31^2 - 2712*beta_31 + 1340))*x_2^12 + ((118*beta_31^2 + 4414*beta_31
  - 18304)*alpha_31 + (286*beta_31^2 + 550*beta_31 - 1952))*x_2^11 + 
  ((21358*beta_31^2 - 105206*beta_31 + 21412)*alpha_31 + (6376*beta_31^2 - 
  8560*beta_31 - 46040))*x_2^10 + ((105653*beta_31^2 - 523857*beta_31 + 
  49926)*alpha_31 - 42360*beta_31^2 + 334872*beta_31 - 505232)*x_2^9 + 
  ((1081448*beta_31^2 - 6091048*beta_31 + 3890512)*alpha_31 - 382338*beta_31^2 +
  2220772*beta_31 - 2659482)*x_2^8 + ((5147092*beta_31^2 - 29143836*beta_31 + 
  20122144)*alpha_31 - 4659756*beta_31^2 + 26695300*beta_31 - 25141440)*x_2^7 + 
  ((27124956*beta_31^2 - 152634716*beta_31 + 110170776)*alpha_31 - 
  32709536*beta_31^2 + 188325768*beta_31 - 157382776)*x_2^6 + 
  ((113068646*beta_31^2 - 641198782*beta_31 + 492348868)*alpha_31 - 
  200407968*beta_31^2 + 1154879552*beta_31 - 924467232)*x_2^5 + 
  ((392645916*beta_31^2 - 2234185868*beta_31 + 1727979752)*alpha_31 - 
  820960708*beta_31^2 + 4720956984*beta_31 - 3715237060)*x_2^4 + 
  ((1205989898*beta_31^2 - 6882210758*beta_31 + 5320863512)*alpha_31 - 
  3281620450*beta_31^2 + 18781055718*beta_31 - 14580403936)*x_2^3 + 
  ((2385691881*beta_31^2 - 13681247237*beta_31 + 10743012110)*alpha_31 - 
  8410091904*beta_31^2 + 48008364744*beta_31 - 37120367960)*x_2^2 + 
  (1/2*(7712921793*beta_31^2 - 44286340893*beta_31 + 34927056958)*alpha_31 - 
  18666972884*beta_31^2 + 106350035412*beta_31 - 81698145992)*x_2 + 
  -18504071059*beta_31^2 + 105509107278*beta_31 - 81205868159
;

// Section MATRIX //////////////////////////////////////////////////////////////

M_30 := Matrix(
[
  [
    1/4*(-beta_31^2 + 9*beta_31 - 14)*alpha_31 + beta_31 - 4,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    0,
    1/4*(-beta_31^2 + 9*beta_31 - 14)*alpha_31 + beta_31 - 4,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    1/4*(15*beta_31^2 - 195*beta_31 + 594)*alpha_31 - 6*beta_31^2 + 18*beta_31 + 48,
    0,
    1/2*(-beta_31 + 6)*alpha_31 + 1/2*(-beta_31^2 + 8*beta_31 - 8),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    (2*beta_31^2 - 26*beta_31 + 156)*alpha_31 - 32*beta_31^2 + 256*beta_31 - 224,
    (beta_31^2 - 13*beta_31 + 78)*alpha_31 - 16*beta_31^2 + 128*beta_31 - 112,
    0,
    1/4*(-beta_31^2 + 9*beta_31 - 14)*alpha_31 + beta_31 - 4,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    1/4*(-255*beta_31^2 + 4135*beta_31 - 15630)*alpha_31 + 460*beta_31^2 - 2920*beta_31 + 2060,
    1/2*(5*beta_31^2 - 25*beta_31 + 270)*alpha_31 - 80*beta_31^2 + 480*beta_31 - 80,
    1/2*(5*beta_31^2 - 5*beta_31 - 110)*alpha_31 - 10*beta_31^2 + 50*beta_31 + 100,
    0,
    alpha_31 - beta_31 + 4,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    (-486*beta_31^2 + 3006*beta_31 - 3396)*alpha_31 + 672*beta_31^2 - 5136*beta_31 + 11664,
    1/4*(-477*beta_31^2 + 2169*beta_31 - 150)*alpha_31 - 222*beta_31^2 + 906*beta_31 + 1872,
    (18*beta_31^2 - 186*beta_31 + 300)*alpha_31 + 48*beta_31^2 - 384*beta_31 + 528,
    1/2*(15*beta_31^2 - 195*beta_31 + 594)*alpha_31 - 12*beta_31^2 + 36*beta_31 + 96,
    0,
    1/2*(-beta_31 + 6)*alpha_31 + 1/2*(-beta_31^2 + 8*beta_31 - 8),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    1/4*(3241*beta_31^2 - 89397*beta_31 + 339934)*alpha_31 - 11865*beta_31^2 + 69069*beta_31 - 76790,
    1/2*(-2877*beta_31^2 + 19817*beta_31 - 29190)*alpha_31 - 420*beta_31^2 + 7980*beta_31 - 16128,
    1/2*(-553*beta_31^2 + 3101*beta_31 - 3990)*alpha_31 - 196*beta_31^2 + 3150*beta_31 - 9702,
    1/2*(21*beta_31^2 - 161*beta_31 + 406)*alpha_31 - 70*beta_31^2 + 406*beta_31 - 364,
    (-14*beta_31^2 + 126*beta_31 - 252)*alpha_31 - 7*beta_31^2 + 91*beta_31 - 322,
    0,
    1/2*(beta_31 - 6)*alpha_31 + 1/2*(-beta_31^2 + 8*beta_31 - 12),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    (33484*beta_31^2 - 157916*beta_31 + 9640)*alpha_31 - 19616*beta_31^2 + 203424*beta_31 - 529472,
    (4080*beta_31^2 - 6032*beta_31 - 67008)*alpha_31 + 30160*beta_31^2 - 141360*beta_31 + 5440,
    (992*beta_31^2 - 5920*beta_31 - 6016)*alpha_31 + 3936*beta_31^2 - 22688*beta_31 - 4736,
    (-5*beta_31^2 + 1313*beta_31 - 7334)*alpha_31 + 2272*beta_31^2 - 13872*beta_31 + 9648,
    (-40*beta_31^2 + 328*beta_31 - 496)*alpha_31 + 256*beta_31 - 768,
    (4*beta_31^2 - 20*beta_31 - 40)*alpha_31 + 16*beta_31^2 - 48*beta_31,
    0,
    1/4*(-beta_31^2 + 9*beta_31 - 14)*alpha_31 + beta_31 - 4,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    1/4*(366543*beta_31^2 - 314883*beta_31 - 7174638)*alpha_31 + 724509*beta_31^2 - 4463595*beta_31 + 4520268,
    (70047*beta_31^2 - 442755*beta_31 + 379458)*alpha_31 + 105228*beta_31^2 - 661716*beta_31 + 761040,
    (23577*beta_31^2 - 162681*beta_31 + 208122)*alpha_31 + 18924*beta_31^2 - 177348*beta_31 + 377280,
    1/2*(-3357*beta_31^2 + 28737*beta_31 - 62766)*alpha_31 + 7884*beta_31^2 - 52092*beta_31 + 58248,
    (342*beta_31^2 - 3681*beta_31 + 10413)*alpha_31 + 1089*beta_31^2 - 9243*beta_31 + 16920,
    (9*beta_31^2 - 9*beta_31 - 198)*alpha_31 - 36*beta_31^2 + 180*beta_31 + 360,
    (9*beta_31^2 - 99*beta_31 + 216)*alpha_31 - 36*beta_31 + 252,
    0,
    alpha_31 - beta_31 + 4,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    (-1951120*beta_31^2 + 9855400*beta_31 - 630120)*alpha_31 - 3349880*beta_31^2 + 16835880*beta_31 - 505280,
    1/4*(205385*beta_31^2 - 4657185*beta_31 + 16292290)*alpha_31 - 2877900*beta_31^2 + 15813040*beta_31 - 9196900,
    (99440*beta_31^2 - 804760*beta_31 + 1411160)*alpha_31 - 279880*beta_31^2 + 1101080*beta_31 + 420800,
    1/2*(-865*beta_31^2 - 30795*beta_31 + 249370)*alpha_31 - 161020*beta_31^2 + 892460*beta_31 - 678120,
    (3700*beta_31^2 - 29500*beta_31 + 52960)*alpha_31 - 5520*beta_31^2 + 19040*beta_31 + 33520,
    1/2*(2405*beta_31^2 - 18005*beta_31 + 16930)*alpha_31 - 3610*beta_31^2 + 17090*beta_31 - 7740,
    (20*beta_31^2 - 220*beta_31 + 480)*alpha_31 - 80*beta_31 + 560,
    1/2*(5*beta_31^2 - 25*beta_31 + 270)*alpha_31 - 80*beta_31^2 + 480*beta_31 - 80,
    0,
    alpha_31 - beta_31 + 4,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    1/4*(-31792233*beta_31^2 + 141763589*beta_31 + 57419890)*alpha_31 - 49239982*beta_31^2 + 294747882*beta_31 - 278914944,
    (-1572351*beta_31^2 + 8482243*beta_31 - 7192482)*alpha_31 - 13931192*beta_31^2 + 82479672*beta_31 - 76499632,
    (-877195*beta_31^2 + 5881502*beta_31 - 8215735)*alpha_31 + 1/2*(-2453781*beta_31^2 + 16242743*beta_31 - 24993848),
    1/2*(-51249*beta_31^2 + 453805*beta_31 - 686334)*alpha_31 - 419694*beta_31^2 + 2643718*beta_31 - 3657940,
    (-30371*beta_31^2 + 264539*beta_31 - 539814)*alpha_31 + 11275*beta_31^2 - 4411*beta_31 - 313698,
    (-847*beta_31^2 + 3091*beta_31 - 24002)*alpha_31 - 1452*beta_31^2 + 10252*beta_31 - 33880,
    1/2*(-1573*beta_31^2 + 13013*beta_31 - 39138)*alpha_31 + 2222*beta_31^2 - 10384*beta_31 - 5038,
    1/2*(-99*beta_31^2 + 759*beta_31 - 506)*alpha_31 - 110*beta_31^2 + 726*beta_31 - 132,
    (-55*beta_31^2 + 451*beta_31 - 682)*alpha_31 - 11*beta_31^2 + 187*beta_31 - 286,
    0,
    -alpha_31 + 1/2*(beta_31^2 - 9*beta_31 + 12),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    (40186542*beta_31^2 - 161343414*beta_31 - 130853724)*alpha_31 + 411671136*beta_31^2 - 2228599488*beta_31 + 1323076320,
    (-14145051*beta_31^2 + 99503103*beta_31 - 176745882)*alpha_31 + 195825624*beta_31^2 - 1100301528*beta_31 + 760388208,
    (-11419096*beta_31^2 + 76248952*beta_31 - 99186256)*alpha_31 + 37557360*beta_31^2 - 203546864*beta_31 + 110599136,
    1/4*(-7881573*beta_31^2 + 50449761*beta_31 - 45893382)*alpha_31 + 14327922*beta_31^2 - 80177382*beta_31 + 58930128,
    (-392388*beta_31^2 + 2672820*beta_31 - 3852792)*alpha_31 + 868080*beta_31^2 - 4587504*beta_31 + 1571424,
    (-90584*beta_31^2 + 492200*beta_31 - 490208)*alpha_31 + 518256*beta_31^2 - 3006784*beta_31 + 2005456,
    (-2904*beta_31^2 + 16824*beta_31 - 28560)*alpha_31 + 8496*beta_31^2 - 43632*beta_31 + 1440,
    1/2*(-5319*beta_31^2 + 34107*beta_31 - 39810)*alpha_31 + 4452*beta_31^2 - 19692*beta_31 + 2688,
    (-36*beta_31^2 + 180*beta_31 - 24)*alpha_31 + 48*beta_31^2 - 240*beta_31 - 96,
    (-18*beta_31^2 + 90*beta_31 - 12)*alpha_31 + 24*beta_31^2 - 120*beta_31 - 48,
    0,
    1/2*(-beta_31 + 6)*alpha_31 + 1/2*(-beta_31^2 + 8*beta_31 - 8),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    1/4*(1183041509*beta_31^2 - 6366785269*beta_31 + 3282762626)*alpha_31 + 4222965786*beta_31^2 - 24493861210*beta_31 + 20796261252,
    1/2*(65719329*beta_31^2 - 531489621*beta_31 + 826490886)*alpha_31 + 1228737718*beta_31^2 - 7136191062*beta_31 + 5979295036,
    (18039970*beta_31^2 - 115770590*beta_31 + 188490120)*alpha_31 + 150131956*beta_31^2 - 868756122*beta_31 + 766670554,
    1/2*(-1358799*beta_31^2 + 2291523*beta_31 + 82525742)*alpha_31 + 50622260*beta_31^2 - 293868276*beta_31 + 277095624,
    1/2*(3659435*beta_31^2 - 24912823*beta_31 + 40806194)*alpha_31 + 1/2*(-3215043*beta_31^2 + 15950701*beta_31 - 3150940),
    (200694*beta_31^2 - 1777542*beta_31 + 2082444)*alpha_31 + 1881516*beta_31^2 - 11654604*beta_31 + 8339864,
    (170495*beta_31^2 - 1231607*beta_31 + 1617278)*alpha_31 - 66326*beta_31^2 + 151398*beta_31 + 62452,
    1/2*(-15665*beta_31^2 + 119405*beta_31 - 215358)*alpha_31 + 12116*beta_31^2 - 35828*beta_31 - 42328,
    1/2*(2639*beta_31^2 - 16523*beta_31 + 26026)*alpha_31 - 2665*beta_31^2 + 23023*beta_31 - 26988,
    (-130*beta_31^2 + 1066*beta_31 - 1612)*alpha_31 - 26*beta_31^2 + 442*beta_31 - 676,
    1/2*(-65*beta_31^2 + 585*beta_31 - 962)*alpha_31 + 78*beta_31 - 234,
    0,
    -alpha_31 + 1/2*(beta_31^2 - 9*beta_31 + 12),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    (2775236268*beta_31^2 - 18646676860*beta_31 + 24934379176)*alpha_31 - 32881206092*beta_31^2 + 184349658668*beta_31 - 128771068440,
    1/4*(9010443757*beta_31^2 - 56127139369*beta_31 + 59125720598)*alpha_31 - 11781298109*beta_31^2 + 66135329057*beta_31 - 47736293934,
    (1044022280*beta_31^2 - 6319165888*beta_31 + 6579801592)*alpha_31 - 2869253408*beta_31^2 + 16135824936*beta_31 - 11067496664,
    (229803021*beta_31^2 - 1321405729*beta_31 + 1207693662)*alpha_31 - 1083449878*beta_31^2 + 6189789942*beta_31 - 4555418812,
    (42330204*beta_31^2 - 261385180*beta_31 + 292150936)*alpha_31 - 82057192*beta_31^2 + 450628808*beta_31 - 281788080,
    1/2*(26636827*beta_31^2 - 160531287*beta_31 + 147738402)*alpha_31 - 31673348*beta_31^2 + 173278462*beta_31 - 121596342,
    (1007188*beta_31^2 - 6620740*beta_31 + 7400344)*alpha_31 - 1067136*beta_31^2 + 5287632*beta_31 - 2758896,
    1/2*(507367*beta_31^2 - 3068779*beta_31 + 2954994)*alpha_31 - 423864*beta_31^2 + 2421552*beta_31 - 1589784,
    (6426*beta_31^2 - 34482*beta_31 + 47628)*alpha_31 - 16604*beta_31^2 + 118412*beta_31 - 121128,
    (1358*beta_31^2 - 5838*beta_31 + 1484)*alpha_31 - 1323*beta_31^2 + 6671*beta_31 - 826,
    (14*beta_31^2 - 14*beta_31 - 308)*alpha_31 + 56*beta_31 - 1064,
    (14*beta_31^2 - 70*beta_31 - 140)*alpha_31 + 14*beta_31^2 - 126*beta_31 + 28,
    0,
    1/2*(beta_31 - 6)*alpha_31 + 1/2*(-beta_31^2 + 8*beta_31 - 12),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    1/2*(45962481225*beta_31^2 - 261403478325*beta_31 + 179392837950)*alpha_31 + 1/2*(-755872496355*beta_31^2 + 4332230996775*beta_31 - 3433856946570),
    1/2*(19826105715*beta_31^2 - 111224970375*beta_31 + 65785734810)*alpha_31 - 102713212410*beta_31^2 + 585952920090*beta_31 - 460326654180,
    1/4*(9658650975*beta_31^2 - 52972830375*beta_31 + 38414010670)*alpha_31 - 18539668985*beta_31^2 + 106730653120*beta_31 - 81832114335,
    1/2*(1387222125*beta_31^2 - 6508271865*beta_31 + 1712565510)*alpha_31 - 6922212375*beta_31^2 + 40288064235*beta_31 - 31420500930,
    1/4*(-161275485*beta_31^2 + 1259079777*beta_31 - 1666827342)*alpha_31 + 1/2*(-407393049*beta_31^2 + 2379879129*beta_31 - 1583913498),
    (60468490*beta_31^2 - 359249410*beta_31 + 329839500)*alpha_31 - 206158660*beta_31^2 + 1118436100*beta_31 - 754900840,
    1/4*(-14426775*beta_31^2 + 89568435*beta_31 - 116011290)*alpha_31 + 1/2*(446025*beta_31^2 - 22979865*beta_31 + 48404010),
    (2021880*beta_31^2 - 13448280*beta_31 + 15886800)*alpha_31 - 2368425*beta_31^2 + 12184245*beta_31 - 6308190,
    1/4*(387045*beta_31^2 - 3117025*beta_31 + 4365830)*alpha_31 + 1/2*(-332835*beta_31^2 + 1329175*beta_31 + 526310),
    (15120*beta_31^2 - 100080*beta_31 + 144960)*alpha_31 - 7230*beta_31^2 + 53430*beta_31 - 27540,
    1/4*(10155*beta_31^2 - 75315*beta_31 + 158310)*alpha_31 - 4620*beta_31^2 + 33765*beta_31 - 26835,
    1/2*(45*beta_31^2 - 345*beta_31 + 870)*alpha_31 + 45*beta_31^2 - 225*beta_31 + 510,
    1/4*(15*beta_31^2 - 75*beta_31 + 810)*alpha_31 + 1/2*(15*beta_31^2 + 105*beta_31 - 690),
    0,
    1/4*(beta_31^2 - 9*beta_31 + 14)*alpha_31 + 1/2*(beta_31^2 - 7*beta_31 + 2),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    (-374683284872*beta_31^2 + 2234034989928*beta_31 - 2159917950448)*alpha_31 + 1733354241984*beta_31^2 - 9816814152128*beta_31 + 7195010786176,
    (-179825261544*beta_31^2 + 1058125315336*beta_31 - 972686458736)*alpha_31 + 601084923584*beta_31^2 - 3422470676544*beta_31 + 2559568865280,
    (-78875118688*beta_31^2 + 465755475872*beta_31 - 416134233472)*alpha_31 + 148874627552*beta_31^2 - 837167880864*beta_31 + 619208316160,
    (-21352858228*beta_31^2 + 125786238020*beta_31 - 107596217464)*alpha_31 + 54261062768*beta_31^2 - 305018391760*beta_31 + 230631816576,
    (-3592744640*beta_31^2 + 21537114240*beta_31 - 19797685440)*alpha_31 + 5095746592*beta_31^2 - 28606890848*beta_31 + 21351939840,
    (-867724400*beta_31^2 + 5005129648*beta_31 - 4110943264)*alpha_31 + 1622746624*beta_31^2 - 9443633280*beta_31 + 7378733952,
    (-69562816*beta_31^2 + 395317824*beta_31 - 352961280)*alpha_31 + 103418560*beta_31^2 - 646579520*beta_31 + 568380160,
    (-12631581*beta_31^2 + 67525977*beta_31 - 46278390)*alpha_31 + 18332512*beta_31^2 - 106971440*beta_31 + 85708848,
    (-484464*beta_31^2 + 1925552*beta_31 + 2233824)*alpha_31 + 460608*beta_31^2 - 2802624*beta_31 + 6651392,
    (-137344*beta_31^2 + 768192*beta_31 - 31168)*alpha_31 + 94912*beta_31^2 - 288960*beta_31 + 206208,
    (3104*beta_31^2 - 40032*beta_31 + 145920)*alpha_31 + 13728*beta_31^2 - 82400*beta_31 + 89344,
    (844*beta_31^2 - 12860*beta_31 + 35656)*alpha_31 + 9104*beta_31^2 - 60592*beta_31 + 50944,
    (64*beta_31 - 192)*alpha_31 + 32*beta_31^2 + 160*beta_31 - 1280,
    (16*beta_31^2 - 208*beta_31 + 480)*alpha_31 + 64*beta_31^2 - 320*beta_31 + 128,
    0,
    1/4*(-beta_31^2 + 9*beta_31 - 14)*alpha_31 + beta_31 - 4,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    1/4*(-20842221028781*beta_31^2 + 118203276051681*beta_31 - 89559500261886)*alpha_31 + 29809422195947*beta_31^2 - 170392542530445*beta_31 + 131852080299092,
    (-1639529862938*beta_31^2 + 9273298361130*beta_31 - 6993774017268)*alpha_31 + 8197126421720*beta_31^2 - 46863513180504*beta_31 + 36053144554224,
    (-533172363570*beta_31^2 + 3070005712066*beta_31 - 2481709239140)*alpha_31 + 1640108593292*beta_31^2 - 9310961828116*beta_31 + 7076645181456,
    (-172718683129*beta_31^2 + 986187711297*beta_31 - 752643404786)*alpha_31 + 609990428164*beta_31^2 - 3449771740684*beta_31 + 2612839286336,
    (-16074504751*beta_31^2 + 94701144163*beta_31 - 80200530386)*alpha_31 + 1/2*(74047480941*beta_31^2 - 410818780999*beta_31 + 294514229072),
    (-9489912448*beta_31^2 + 56038413556*beta_31 - 48730984092)*alpha_31 + 18977061648*beta_31^2 - 107141193856*beta_31 + 78913845232,
    (-435016621*beta_31^2 + 2645810827*beta_31 - 2488288028)*alpha_31 + 1118549340*beta_31^2 - 6221887460*beta_31 + 4014568496,
    1/2*(-412970613*beta_31^2 + 2449997313*beta_31 - 2427345238)*alpha_31 + 184092116*beta_31^2 - 1105022372*beta_31 + 866503736,
    (-17922301*beta_31^2 + 109340634*beta_31 - 125493609)*alpha_31 + 27374369*beta_31^2 - 163251323*beta_31 + 117146456,
    (-1933206*beta_31^2 + 11484622*beta_31 - 11223876)*alpha_31 - 1140020*beta_31^2 + 6175692*beta_31 - 1583312,
    (-347004*beta_31^2 + 2093176*beta_31 - 2464524)*alpha_31 - 77486*beta_31^2 + 195738*beta_31 + 1116016,
    (-8925*beta_31^2 + 42449*beta_31 + 20706)*alpha_31 - 4964*beta_31^2 + 14892*beta_31 + 51136,
    1/2*(-9231*beta_31^2 + 59993*beta_31 - 32436)*alpha_31 + 1/2*(-18377*beta_31^2 + 104635*beta_31 - 816),
    (68*beta_31^2 - 884*beta_31 + 2040)*alpha_31 + 204*beta_31^2 - 1564*beta_31 + 1768,
    (17*beta_31^2 - 221*beta_31 + 510)*alpha_31 + 34*beta_31^2 - 442*beta_31 + 748,
    0,
    1/2*(-beta_31 + 6)*alpha_31 + 1/2*(-beta_31^2 + 8*beta_31 - 8),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    (19388321159400*beta_31^2 - 114550709655384*beta_31 + 102567240583776)*alpha_31 - 43514526072384*beta_31^2 + 245607413893344*beta_31 - 183220928145504,
    1/4*(38583183143583*beta_31^2 - 225631396631187*beta_31 + 192335025951090)*alpha_31 - 16879368846771*beta_31^2 + 95624988351813*beta_31 - 73511932221684,
    (3819315630696*beta_31^2 - 22130152151256*beta_31 + 18268985078112)*alpha_31 - 4220786706000*beta_31^2 + 24198733072656*beta_31 - 18766519052640,
    (999950047245*beta_31^2 - 5737470494409*beta_31 + 4593778066134)*alpha_31 - 1602810227484*beta_31^2 + 9308293307172*beta_31 - 7397909730864,
    (171908141508*beta_31^2 - 980746759692*beta_31 + 793920615552)*alpha_31 - 181842692796*beta_31^2 + 1075817449620*beta_31 - 890203857120,
    (28325299593*beta_31^2 - 154115057817*beta_31 + 101320863594)*alpha_31 - 33820472100*beta_31^2 + 198318594924*beta_31 - 171391752768,
    (2871585576*beta_31^2 - 15204788856*beta_31 + 7093531008)*alpha_31 - 3107407968*beta_31^2 + 18307016064*beta_31 - 20548380960,
    1/2*(677484369*beta_31^2 - 3603619053*beta_31 + 251025822)*alpha_31 - 889337376*beta_31^2 + 4718583864*beta_31 - 3729173256,
    (-18795228*beta_31^2 + 200061972*beta_31 - 594312768)*alpha_31 - 139099392*beta_31^2 + 823877664*beta_31 - 784102752,
    (1081638*beta_31^2 + 9511911*beta_31 - 61253883)*alpha_31 - 53524431*beta_31^2 + 316866789*beta_31 - 236873304,
    (-881028*beta_31^2 + 7331148*beta_31 - 13926528)*alpha_31 - 4978584*beta_31^2 + 27376488*beta_31 - 15082848,
    (52185*beta_31^2 + 251655*beta_31 - 1912902)*alpha_31 - 1241160*beta_31^2 + 6770712*beta_31 - 4442688,
    (108*beta_31^2 - 1692*beta_31 + 9288)*alpha_31 - 52092*beta_31^2 + 259524*beta_31 - 16560,
    (5157*beta_31^2 - 32967*beta_31 + 15192)*alpha_31 - 11880*beta_31^2 + 49572*beta_31 - 900,
    (72*beta_31 - 216)*alpha_31 - 144*beta_31^2 + 576*beta_31 + 720,
    1/2*(9*beta_31^2 - 45*beta_31 + 486)*alpha_31 - 144*beta_31^2 + 864*beta_31 - 144,
    0,
    alpha_31 - beta_31 + 4,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    1/4*(2244799278573731*beta_31^2 - 12812076691276711*beta_31 + 9877870784743242)*alpha_31 - 1919592056288168*beta_31^2 + 10944029311496764*beta_31 - 8424393426385804,
    (175525869242346*beta_31^2 - 1003089638602106*beta_31 + 777540931087764)*alpha_31 - 537721042358944*beta_31^2 + 3062635012306800*beta_31 - 2351374481382832,
    1/2*(111091931940099*beta_31^2 - 637860432047167*beta_31 + 504444219623730)*alpha_31 - 107961070439102*beta_31^2 + 615273726769794*beta_31 - 472168809856056,
    (18298124132435*beta_31^2 - 104818214581055*beta_31 + 81875539485282)*alpha_31 - 41247359830852*beta_31^2 + 235145739959884*beta_31 - 179768711906240,
    (2138725086579*beta_31^2 - 12300968628899*beta_31 + 9954088503214)*alpha_31 - 3102553699506*beta_31^2 + 17762305714614*beta_31 - 13554266353920,
    (833105727150*beta_31^2 - 4779527666718*beta_31 + 3875233081948)*alpha_31 - 1026931821560*beta_31^2 + 5898098413624*beta_31 - 4556006728048,
    (68085119859*beta_31^2 - 391387017129*beta_31 + 322992713120)*alpha_31 - 91065271342*beta_31^2 + 520776464058*beta_31 - 396827731824,
    1/2*(34288591889*beta_31^2 - 198795780941*beta_31 + 163935846398)*alpha_31 - 75148952*beta_31^2 + 795390160*beta_31 - 8763349784,
    1/2*(4004543037*beta_31^2 - 23137040297*beta_31 + 19188596166)*alpha_31 - 988876622*beta_31^2 + 5807976050*beta_31 - 5636690936,
    (167335090*beta_31^2 - 939545554*beta_31 + 577824276)*alpha_31 + 150032816*beta_31^2 - 784290208*beta_31 + 283442608,
    (33892713*beta_31^2 - 197665113*beta_31 + 135818954)*alpha_31 + 40075579*beta_31^2 - 219661185*beta_31 + 76422560,
    (799406*beta_31^2 - 1786798*beta_31 - 7085556)*alpha_31 - 1995038*beta_31^2 + 13228750*beta_31 - 13561212,
    1/2*(169461*beta_31^2 + 168055*beta_31 - 3438354)*alpha_31 + 614327*beta_31^2 - 2199839*beta_31 - 896002,
    (12996*beta_31^2 - 62700*beta_31 - 32224)*alpha_31 - 31236*beta_31^2 + 146452*beta_31 - 81624,
    1/2*(-2413*beta_31^2 + 36309*beta_31 - 99674)*alpha_31 + 6099*beta_31^2 - 32167*beta_31 + 1178,
    1/2*(57*beta_31^2 - 437*beta_31 + 1102)*alpha_31 - 190*beta_31^2 + 1102*beta_31 - 988,
    (19*beta_31^2 - 95*beta_31 - 190)*alpha_31 + 19*beta_31^2 - 171*beta_31 + 38,
    0,
    1/2*(beta_31 - 6)*alpha_31 + 1/2*(-beta_31^2 + 8*beta_31 - 12),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    (283978919805450*beta_31^2 - 1542801779364290*beta_31 + 883193176602060)*alpha_31 - 2186983724176320*beta_31^2 + 12433380446320800*beta_31 - 9504765917311520,
    (-97354422291735*beta_31^2 + 569327831180795*beta_31 - 500554385563890)*alpha_31 - 483309227870640*beta_31^2 + 2716662416758560*beta_31 - 1999064543268400,
    (-49887294597800*beta_31^2 + 281519929735640*beta_31 - 219529471922720)*alpha_31 - 115095061262320*beta_31^2 + 646118790765200*beta_31 - 473377528435520,
    1/4*(-9741634525575*beta_31^2 + 40968229985455*beta_31 + 3767000754850)*alpha_31 - 34908987607340*beta_31^2 + 195562197636560*beta_31 - 136022944359780,
    (-2372814651616*beta_31^2 + 13007274978544*beta_31 - 7514177740272)*alpha_31 + 619634953184*beta_31^2 - 3555104317024*beta_31 + 5655979498048,
    (864144547540*beta_31^2 - 5144945728380*beta_31 + 5476292146240)*alpha_31 + 28175204680*beta_31^2 + 84825683240*beta_31 + 181269175680,
    (67893356600*beta_31^2 - 471377165320*beta_31 + 785012361120)*alpha_31 + 355990675600*beta_31^2 - 2057224091120*beta_31 + 1741733773760,
    1/2*(51402224155*beta_31^2 - 330360930295*beta_31 + 384574162690)*alpha_31 + 186470381500*beta_31^2 - 1067886127340*beta_31 + 778427831400,
    (4652833300*beta_31^2 - 32209488500*beta_31 + 44830817640)*alpha_31 + 31349309440*beta_31^2 - 177881477760*beta_31 + 127195701120,
    (-419364718*beta_31^2 + 1722568302*beta_31 + 458841204)*alpha_31 + 8061861752*beta_31^2 - 45262000872*beta_31 + 32027588864,
    (-4431840*beta_31^2 + 21564240*beta_31 - 15069200)*alpha_31 + 928004160*beta_31^2 - 5054633120*beta_31 + 2967604640,
    1/2*(-77558675*beta_31^2 + 461941795*beta_31 - 319447310)*alpha_31 + 170123030*beta_31^2 - 916895150*beta_31 + 582493540,
    (-1554280*beta_31^2 + 12401400*beta_31 - 22586560)*alpha_31 + 9593040*beta_31^2 - 48999440*beta_31 + 17933280,
    (-575640*beta_31^2 + 3437200*beta_31 - 4158040)*alpha_31 + 2451360*beta_31^2 - 14005200*beta_31 + 7492560,
    (-7280*beta_31^2 + 80160*beta_31 - 246640)*alpha_31 + 38880*beta_31^2 - 220480*beta_31 + 65760,
    1/2*(-10125*beta_31^2 + 75185*beta_31 - 155790)*alpha_31 + 9040*beta_31^2 - 39040*beta_31 - 12880,
    (20*beta_31^2 - 20*beta_31 - 440)*alpha_31 - 80*beta_31^2 + 400*beta_31 + 800,
    (-50*beta_31^2 + 450*beta_31 - 740)*alpha_31 - 80*beta_31^2 + 640*beta_31 - 560,
    0,
    alpha_31 - beta_31 + 4,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    1/4*(-168397065996885999*beta_31^2 + 960949551836200647*beta_31 - 740589752474374782)*alpha_31 + 97053658745152452*beta_31^2 - 553665304783806264*beta_31 + 426238754285222340,
    1/2*(-26794451386958787*beta_31^2 + 152970097953021279*beta_31 - 118172215482902994)*alpha_31 + 27572119974162540*beta_31^2 - 157324223471721516*beta_31 + 121110433275267576,
    1/2*(-7971205951909613*beta_31^2 + 45506970823203085*beta_31 - 35343485055270658)*alpha_31 + 4637696891014362*beta_31^2 - 26512078648783406*beta_31 + 20502494376241024,
    (-1321867140029541*beta_31^2 + 7535425007621553*beta_31 - 5821563687215094)*alpha_31 + 1874158189234296*beta_31^2 - 10701577026344904*beta_31 + 8242912706972832,
    1/2*(-336305639990187*beta_31^2 + 1921234988720019*beta_31 - 1492706285897862)*alpha_31 + 1/2*(263018834105601*beta_31^2 - 1501442147004387*beta_31 + 1177282311198000),
    (-53847204241740*beta_31^2 + 308106059638020*beta_31 - 238775761041440)*alpha_31 + 24545352294932*beta_31^2 - 139631842618604*beta_31 + 112443274387024,
    (-5669968989942*beta_31^2 + 32335119174882*beta_31 - 24525956461152)*alpha_31 + 4652993866470*beta_31^2 - 26595618914658*beta_31 + 21199706708592,
    1/2*(-1991343367167*beta_31^2 + 11294327703267*beta_31 - 8325781790466)*alpha_31 - 513755236764*beta_31^2 + 2791317090156*beta_31 - 1692676311816,
    1/2*(-296954827519*beta_31^2 + 1675258854115*beta_31 - 1197707785218)*alpha_31 + 45380123222*beta_31^2 - 269643980130*beta_31 + 262592459136,
    (-11702471424*beta_31^2 + 60712660344*beta_31 - 28336666344)*alpha_31 + 4652848746*beta_31^2 - 31147870026*beta_31 + 34022943108,
    1/2*(-4058911185*beta_31^2 + 21548588733*beta_31 - 11247671694)*alpha_31 - 2315456913*beta_31^2 + 11840760645*beta_31 - 6140831718,
    (-262592575*beta_31^2 + 1437971283*beta_31 - 691908882)*alpha_31 + 708561728*beta_31^2 - 3878757904*beta_31 + 2755699184,
    1/2*(-22562463*beta_31^2 + 65457315*beta_31 + 148653918)*alpha_31 - 57304401*beta_31^2 + 316786029*beta_31 - 176258334,
    (-3942666*beta_31^2 + 22631658*beta_31 - 19583172)*alpha_31 + 13936944*beta_31^2 - 79579752*beta_31 + 52668168,
    (-321965*beta_31^2 + 1715021*beta_31 + 339710)*alpha_31 - 22568*beta_31^2 + 447916*beta_31 + 75684,
    1/2*(-63777*beta_31^2 + 422205*beta_31 - 590142)*alpha_31 + 76860*beta_31^2 - 410508*beta_31 + 261576,
    1/2*(-5691*beta_31^2 + 20895*beta_31 + 8358)*alpha_31 + 14238*beta_31^2 - 92862*beta_31 + 83916,
    (-210*beta_31^2 + 1722*beta_31 - 2604)*alpha_31 - 42*beta_31^2 + 714*beta_31 - 1092,
    1/2*(-63*beta_31^2 + 315*beta_31 - 42)*alpha_31 + 63*beta_31^2 - 399*beta_31 + 630,
    0,
    -alpha_31 + 1/2*(beta_31^2 - 9*beta_31 + 12),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    (-149477253558765990*beta_31^2 + 852341586189044094*beta_31 - 653002515854945476)*alpha_31 + 345928239013898640*beta_31^2 - 1971200721067462016*beta_31 + 1510381450915069040,
    1/4*(-156607262417861189*beta_31^2 + 895283466700551665*beta_31 - 693934533875999702)*alpha_31 + 98152177115784858*beta_31^2 - 558951789417263022*beta_31 + 426352725155063872,
    (-11033818044648278*beta_31^2 + 63014850386188030*beta_31 - 49257411397440532)*alpha_31 + 17263338763465432*beta_31^2 - 98642006817155032*beta_31 + 75493203599186032,
    1/2*(-8677382235994307*beta_31^2 + 49654226545248743*beta_31 - 39433004293284074)*alpha_31 + 5365938514543552*beta_31^2 - 30657419339617840*beta_31 + 23326001733640144,
    (-470407118917032*beta_31^2 + 2714091013779464*beta_31 - 2241716922278064)*alpha_31 - 284087894030160*beta_31^2 + 1628571143388816*beta_31 - 1268735537424608,
    (-202822266506387*beta_31^2 + 1171747008007510*beta_31 - 951248309441815)*alpha_31 + 1/2*(-469534722105845*beta_31^2 + 2682356591062071*beta_31 - 1989218440839256),
    (-17064471607040*beta_31^2 + 101788464506256*beta_31 - 92886724519600)*alpha_31 - 71356201562184*beta_31^2 + 407012424464888*beta_31 - 306623963147744,
    1/2*(-3246134881363*beta_31^2 + 19120869144839*beta_31 - 15492479695418)*alpha_31 - 27496358352496*beta_31^2 + 155599851612832*beta_31 - 114911344215536,
    (-89976705610*beta_31^2 + 547196952258*beta_31 - 568443445900)*alpha_31 - 4364222618580*beta_31^2 + 24550850406148*beta_31 - 17686540005464,
    (129260378841*beta_31^2 - 768807187489*beta_31 + 651206818482)*alpha_31 - 893018901313*beta_31^2 + 5008717100849*beta_31 - 3635904490042,
    (12049986454*beta_31^2 - 78461361022*beta_31 + 95352121172)*alpha_31 - 110300699476*beta_31^2 + 613182485828*beta_31 - 415052768152,
    (4376217571*beta_31^2 - 25584557559*beta_31 + 23617848826)*alpha_31 - 16571056106*beta_31^2 + 94325868978*beta_31 - 65965973436,
    (192309084*beta_31^2 - 1403598284*beta_31 + 2387163240)*alpha_31 - 1055557272*beta_31^2 + 5927636792*beta_31 - 3778155216,
    1/2*(134540307*beta_31^2 - 830258979*beta_31 + 987028878)*alpha_31 - 137637610*beta_31^2 + 746405880*beta_31 - 435995758,
    (-691372*beta_31^2 + 1617132*beta_31 + 10067464)*alpha_31 + 537680*beta_31^2 - 3291200*beta_31 - 1921040,
    1/2*(1090639*beta_31^2 - 8531347*beta_31 + 12781890)*alpha_31 + 520916*beta_31^2 - 3982660*beta_31 + 3399704,
    (-15818*beta_31^2 + 86306*beta_31 - 135212)*alpha_31 + 47212*beta_31^2 - 262460*beta_31 + 77352,
    (-3223*beta_31^2 + 18755*beta_31 - 27082)*alpha_31 + 7865*beta_31^2 - 27049*beta_31 - 19734,
    (-66*beta_31^2 + 330*beta_31 - 44)*alpha_31 + 132*beta_31^2 - 836*beta_31 + 1320,
    (-110*beta_31^2 + 902*beta_31 - 1364)*alpha_31 - 22*beta_31^2 + 374*beta_31 - 572,
    0,
    -alpha_31 + 1/2*(beta_31^2 - 9*beta_31 + 12),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    1/4*(9405101280922762435*beta_31^2 - 53622618953927809927*beta_31 + 41229474115682059210)*alpha_31 - 3423921941135288462*beta_31^2 + 19537310445777810542*beta_31 - 15051351671610484588,
    1/2*(1521770915102606323*beta_31^2 - 8675267010297441831*beta_31 + 6669109445054866170)*alpha_31 - 952895660184884816*beta_31^2 + 5438403048279683112*beta_31 - 4194819156668863016,
    (208197578450636443*beta_31^2 - 1187921722176631595*beta_31 + 914007139962235486)*alpha_31 - 74467028884788762*beta_31^2 + 424726503673735966*beta_31 - 332950044020992528,
    1/2*(139853550567515993*beta_31^2 - 797797612657652549*beta_31 + 611582379757208798)*alpha_31 - 46919397395000628*beta_31^2 + 267098982028903172*beta_31 - 206432755578065912,
    1/2*(18620505666846993*beta_31^2 - 106087428529557465*beta_31 + 80766521758626402)*alpha_31 - 3471735856822841*beta_31^2 + 19922397056515635*beta_31 - 15867268157270312,
    (2542053252168760*beta_31^2 - 14457190482544472*beta_31 + 10970294518539920)*alpha_31 + 186575207813944*beta_31^2 - 981788060209752*beta_31 + 602936073980048,
    (363047474871431*beta_31^2 - 2053321215934039*beta_31 + 1523405571045334)*alpha_31 - 407909961158972*beta_31^2 + 2334871229398996*beta_31 - 1801039983460384,
    (54736677334003*beta_31^2 - 307127596684815*beta_31 + 221447225679666)*alpha_31 - 13405725017833*beta_31^2 + 79144004732989*beta_31 - 66860234490678,
    1/4*(45907416894133*beta_31^2 - 259782096072785*beta_31 + 191337909984006)*alpha_31 + 1/2*(-28319947101999*beta_31^2 + 160837702170651*beta_31 - 121123463784826),
    (1652359827398*beta_31^2 - 9348094983774*beta_31 + 6604069981764)*alpha_31 - 3818686371474*beta_31^2 + 21500244538170*beta_31 - 16111505028076,
    1/4*(900202931953*beta_31^2 - 5082918196613*beta_31 + 3775832909382)*alpha_31 + 1/2*(-374333683811*beta_31^2 + 2106768035451*beta_31 - 1526984932934),
    1/2*(103773756695*beta_31^2 - 592890938539*beta_31 + 467642407938)*alpha_31 - 146689135339*beta_31^2 + 834367917287*beta_31 - 606823826306,
    1/4*(15071450603*beta_31^2 - 87106583503*beta_31 + 64718483898)*alpha_31 + 1/2*(-6057478927*beta_31^2 + 32973924539*beta_31 - 23469565562),
    (915488274*beta_31^2 - 5388561578*beta_31 + 5107767228)*alpha_31 - 2088868740*beta_31^2 + 11719885428*beta_31 - 8252810872,
    1/4*(279178117*beta_31^2 - 1547659489*beta_31 + 1185139814)*alpha_31 + 1/2*(-253130801*beta_31^2 + 1488840485*beta_31 - 1128888806),
    (9283352*beta_31^2 - 61022128*beta_31 + 70111544)*alpha_31 - 9456105*beta_31^2 + 48703213*beta_31 - 34837318,
    1/4*(5065221*beta_31^2 - 29925921*beta_31 + 24713638)*alpha_31 + 1/2*(-3006859*beta_31^2 + 16243543*beta_31 - 13969970),
    (27140*beta_31^2 - 204884*beta_31 + 377752)*alpha_31 - 17158*beta_31^2 + 184414*beta_31 - 233220,
    1/4*(41285*beta_31^2 - 254633*beta_31 + 260222)*alpha_31 + 1/2*(-20401*beta_31^2 + 147453*beta_31 - 175214),
    1/2*(-207*beta_31^2 + 1587*beta_31 - 1058)*alpha_31 - 23*beta_31^2 + 667*beta_31 - 1426,
    1/4*(23*beta_31^2 - 115*beta_31 + 1242)*alpha_31 + 1/2*(23*beta_31^2 + 161*beta_31 - 1058),
    0,
    1/4*(beta_31^2 - 9*beta_31 + 14)*alpha_31 + 1/2*(beta_31^2 - 7*beta_31 + 2),
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    (16061530847291628516*beta_31^2 - 91595015223685288596*beta_31 + 70498206454344120696)*alpha_31 - 21047326749072055968*beta_31^2 + 120034335995557171104*beta_31 - 92169021168221741376,
    (4834554650185363848*beta_31^2 - 27583504372361769000*beta_31 + 21300909594933998640)*alpha_31 - 5916561446575569744*beta_31^2 + 33742473823966527408*beta_31 - 25892670461591679552,
    (1294775593593185504*beta_31^2 - 7391131292263621216*beta_31 + 5708979454560003392)*alpha_31 - 205760343245283520*beta_31^2 + 1171122317092992064*beta_31 - 920014773713388032,
    (454377648357383379*beta_31^2 - 2597199481918917879*beta_31 + 2014747910037734538)*alpha_31 - 21057293182999176*beta_31^2 + 116891224978157256*beta_31 - 96532809202204944,
    (48840571916715336*beta_31^2 - 279696794704299144*beta_31 + 218049172745078160)*alpha_31 + 99750677658004848*beta_31^2 - 568331951671781328*beta_31 + 432664068428989824,
    (13609619798682540*beta_31^2 - 77693898519642924*beta_31 + 59768644940300728)*alpha_31 + 47149230141832232*beta_31^2 - 268004092735112376*beta_31 + 203044558290574144,
    (890001132994128*beta_31^2 - 5077211644920336*beta_31 + 3970759614753888)*alpha_31 + 8859699096057888*beta_31^2 - 50302774952847648*beta_31 + 38019546673688640,
    1/4*(-489983192579589*beta_31^2 + 2975790207149697*beta_31 - 2812713503097030)*alpha_31 + 2796245595921618*beta_31^2 - 15867770614351878*beta_31 + 11969375722850256,
    (-26170658712824*beta_31^2 + 157654155867736*beta_31 - 152056010687696)*alpha_31 + 407059450348544*beta_31^2 - 2307209015855040*beta_31 + 1718426200309568,
    (-13687632816384*beta_31^2 + 79640741295936*beta_31 - 69058688022720)*alpha_31 + 67498642002096*beta_31^2 - 384640449407088*beta_31 + 288470687429664,
    (-1343827666704*beta_31^2 + 8258052862608*beta_31 - 8867821948704)*alpha_31 + 8400660074880*beta_31^2 - 47620191913536*beta_31 + 34939288828224,
    (-314804750140*beta_31^2 + 1849989695036*beta_31 - 1698594677208)*alpha_31 + 724062521488*beta_31^2 - 4073725824160*beta_31 + 2981075684560,
    (-4351601904*beta_31^2 + 37298116080*beta_31 - 84952579680)*alpha_31 + 43702393920*beta_31^2 - 248555886336*beta_31 + 196857675456,
    (-3118891512*beta_31^2 + 20539857912*beta_31 - 22913952432)*alpha_31 - 2141858400*beta_31^2 + 14035254912*beta_31 - 10884239904,
    (387776560*beta_31^2 - 2157209840*beta_31 + 1848861216)*alpha_31 - 653791200*beta_31^2 + 3588863072*beta_31 - 1791481920,
    1/2*(75054321*beta_31^2 - 428189469*beta_31 + 331587726)*alpha_31 - 139370940*beta_31^2 + 716142708*beta_31 - 391473024,
    (6947256*beta_31^2 - 45428760*beta_31 + 51116880)*alpha_31 - 6028032*beta_31^2 + 28692288*beta_31 - 14507712,
    (1395048*beta_31^2 - 9837736*beta_31 + 12510928)*alpha_31 - 1255504*beta_31^2 + 5604304*beta_31 - 934816,
    (18000*beta_31^2 - 109200*beta_31 + 157152)*alpha_31 - 35424*beta_31^2 + 257376*beta_31 - 292032,
    (4794*beta_31^2 - 37698*beta_31 + 104988)*alpha_31 - 12312*beta_31^2 + 95160*beta_31 - 80592,
    (48*beta_31^2 - 528*beta_31 + 1152)*alpha_31 + 144*beta_31^2 - 1008*beta_31 + 192,
    (24*beta_31^2 - 264*beta_31 + 576)*alpha_31 + 72*beta_31^2 - 504*beta_31 + 96,
    0,
    1/2*(-beta_31 + 6)*alpha_31 + 1/2*(-beta_31^2 + 8*beta_31 - 8),
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    1/4*(-368569466916811671825*beta_31^2 + 2101711809107561578125*beta_31 - 1613738779992993679550)*alpha_31 + 50550245895601570925*beta_31^2 - 288236436634264302675*beta_31 + 222412187631618562100,
    (-30369211166832878675*beta_31^2 + 173155621163136658575*beta_31 - 132772248221157735250)*alpha_31 + 12353860598758592500*beta_31^2 - 70437705302303947100*beta_31 + 54518080255095422400,
    (-7285396372467583825*beta_31^2 + 41520938338555305625*beta_31 - 31804334937511511650)*alpha_31 - 4401668590254661400*beta_31^2 + 25035821800271603400*beta_31 - 19099990468293849600,
    1/2*(-5207686125314741275*beta_31^2 + 29654746940117223175*beta_31 - 22667939671999276850)*alpha_31 + 274183155825624300*beta_31^2 - 1586126066939200300*beta_31 + 1211164873307195000,
    1/2*(-856562010635304135*beta_31^2 + 4868194807294024635*beta_31 - 3696538314657634050)*alpha_31 + 1/2*(765777618004899535*beta_31^2 - 4375023849140887085*beta_31 + 3362977139326087600),
    (-109341052555807050*beta_31^2 + 621823168114162450*beta_31 - 473703854569810300)*alpha_31 + 67016461970306200*beta_31^2 - 381056994260231500*beta_31 + 288828948974356300,
    1/2*(-54900553650519125*beta_31^2 + 312712256998154325*beta_31 - 238289436799075250)*alpha_31 + 61078132480315325*beta_31^2 - 347336959585061625*beta_31 + 264422264253437750,
    1/2*(-10175319624440075*beta_31^2 + 58109241801863775*beta_31 - 44469561912767050)*alpha_31 + 11432782167523500*beta_31^2 - 64927129794629100*beta_31 + 49381867923915000,
    (-1219857535617300*beta_31^2 + 6978013111697325*beta_31 - 5448874456063075)*alpha_31 + 2646883046874000*beta_31^2 - 15045298920093850*beta_31 + 11351013314531550,
    (-245135711637880*beta_31^2 + 1400419287398000*beta_31 - 1091082859585560)*alpha_31 + 628399919466660*beta_31^2 - 3580553901996700*beta_31 + 2708830655315280,
    (-32244985564700*beta_31^2 + 185795478289800*beta_31 - 150445592294300)*alpha_31 + 54949727817250*beta_31^2 - 311963497425550*beta_31 + 233967750040600,
    (-7700803544900*beta_31^2 + 44246855441700*beta_31 - 35927792301000)*alpha_31 + 15797343613000*beta_31^2 - 89631826170200*beta_31 + 67097354662400,
    (-628393929300*beta_31^2 + 3618678815400*beta_31 - 2968498064900)*alpha_31 + 835398597900*beta_31^2 - 4771238139100*beta_31 + 3647816279400,
    (-133998741550*beta_31^2 + 791955918550*beta_31 - 688208020100)*alpha_31 + 163426227700*beta_31^2 - 912082913300*beta_31 + 687530813800,
    (-12527788785*beta_31^2 + 72525721705*beta_31 - 57667261490)*alpha_31 + 12156084760*beta_31^2 - 68346830900*beta_31 + 54316935940,
    1/2*(-1953943025*beta_31^2 + 11656246125*beta_31 - 11208609150)*alpha_31 + 172364300*beta_31^2 - 1609745100*beta_31 + 2238195000,
    1/2*(-364193675*beta_31^2 + 2085395375*beta_31 - 1648446650)*alpha_31 + 100932000*beta_31^2 - 640597100*beta_31 + 588659300,
    (1201250*beta_31^2 - 11828650*beta_31 + 11729900)*alpha_31 - 11476300*beta_31^2 + 57188100*beta_31 - 25389600,
    (-1178650*beta_31^2 + 6293350*beta_31 - 5501800)*alpha_31 - 1129850*beta_31^2 + 5333350*beta_31 - 1089800,
    (5825*beta_31^2 - 19325*beta_31 + 128350)*alpha_31 - 118600*beta_31^2 + 809800*beta_31 - 693200,
    1/2*(-17625*beta_31^2 + 128975*beta_31 - 111900)*alpha_31 + 1/2*(-65425*beta_31^2 + 405075*beta_31 - 230000),
    (25*beta_31^2 - 25*beta_31 - 550)*alpha_31 + 100*beta_31 - 1900,
    1/2*(25*beta_31^2 - 125*beta_31 - 250)*alpha_31 - 25*beta_31^2 - 75*beta_31 + 50,
    0,
    1/2*(beta_31 - 6)*alpha_31 + 1/2*(-beta_31^2 + 8*beta_31 - 12),
    0,
    0,
    0,
    0,
    0
  ],
  [
    (-1125386085271744419032*beta_31^2 + 6419052515974319867776*beta_31 - 4938846301650746752488)*alpha_31 + 417067275043858707112*beta_31^2 - 2376806352015653930840*beta_31 + 1826033471193920465568,
    1/4*(-1406913249213016974923*beta_31^2 + 8026653827322725685467*beta_31 - 6180527694643966638910)*alpha_31 + 72608390166525589142*beta_31^2 - 413512887160932568230*beta_31 + 318419453251548082252,
    (-81064774950415930648*beta_31^2 + 462358004391665417568*beta_31 - 355429227709613419336)*alpha_31 - 110762833751073179832*beta_31^2 + 631249167564232204936*beta_31 - 483829365065019993760,
    1/2*(-54698404254363831923*beta_31^2 + 311989973188261388943*beta_31 - 240086688496914449970)*alpha_31 - 39221525715218761148*beta_31^2 + 223427163953352672196*beta_31 - 171184936199455520368,
    (-2447617753058114234*beta_31^2 + 13926566405387526098*beta_31 - 10631746539321885900)*alpha_31 - 12524468791577316808*beta_31^2 + 71336757460314347872*beta_31 - 54619358743740708632,
    (-404244466580546150*beta_31^2 + 2282120697022816026*beta_31 - 1684784461630559640)*alpha_31 - 4939577910491067896*beta_31^2 + 28135622384114249914*beta_31 - 21522958652441936534,
    (-15428925094806262*beta_31^2 + 84268960346931958*beta_31 - 50319013970006236)*alpha_31 - 708482812898955068*beta_31^2 + 4036007821642764188*beta_31 - 3081115084651647992,
    (21194700303689159*beta_31^2 - 122551682219637671*beta_31 + 102259131121612166)*alpha_31 - 192346928393494186*beta_31^2 + 1096618351549967714*beta_31 - 837811797903183116,
    (2286974775554352*beta_31^2 - 13457328249378208*beta_31 + 12146767131336240)*alpha_31 - 24100263054087376*beta_31^2 + 137191197722471568*beta_31 - 104265914476788064,
    1/2*(1334380410966395*beta_31^2 - 7747446433631047*beta_31 + 6584805889616786)*alpha_31 + 1/2*(-5144569164171203*beta_31^2 + 29265998055928205*beta_31 - 22423329877530556),
    (35132991741848*beta_31^2 - 220607399937496*beta_31 + 252934813276080)*alpha_31 - 321546375842120*beta_31^2 + 1831200665806200*beta_31 - 1409339497236320,
    (-257622706640*beta_31^2 - 1246661372216*beta_31 + 6337626371960)*alpha_31 + 22000777866808*beta_31^2 - 125950107131368*beta_31 + 91832466406720,
    (-2440998879020*beta_31^2 + 13711241934156*beta_31 - 10323028202136)*alpha_31 + 2583638921448*beta_31^2 - 14291796003784*beta_31 + 8585481194160,
    (-413513276241*beta_31^2 + 2410909123337*beta_31 - 1952119586482)*alpha_31 + 1263141201738*beta_31^2 - 7014469703514*beta_31 + 5055019477716,
    (-91138068580*beta_31^2 + 544897466516*beta_31 - 496100170488)*alpha_31 + 99010235792*beta_31^2 - 535786747392*beta_31 + 346468833776,
    1/2*(-22362783937*beta_31^2 + 136482605805*beta_31 - 132593769646)*alpha_31 + 19864550888*beta_31^2 - 110544740696*beta_31 + 74419673952,
    (-1059492616*beta_31^2 + 6430458216*beta_31 - 6748745328)*alpha_31 + 952159936*beta_31^2 - 5689027968*beta_31 + 4317516736,
    1/2*(-237041389*beta_31^2 + 1505143809*beta_31 - 2084369950)*alpha_31 + 146825107*beta_31^2 - 900868397*beta_31 + 621212748,
    (-5862688*beta_31^2 + 38320464*beta_31 - 50725584)*alpha_31 + 930488*beta_31^2 - 6748456*beta_31 + 16947840,
    (-852397*beta_31^2 + 6765785*beta_31 - 11865958)*alpha_31 - 218192*beta_31^2 + 2007512*beta_31 + 468936,
    (-28262*beta_31^2 + 228774*beta_31 - 399100)*alpha_31 - 12064*beta_31^2 + 35672*beta_31 + 182936,
    1/2*(-5681*beta_31^2 + 62153*beta_31 - 179218)*alpha_31 + 13260*beta_31^2 - 97734*beta_31 + 120198,
    (-130*beta_31^2 + 1066*beta_31 - 1612)*alpha_31 - 52*beta_31^2 + 52*beta_31 + 1144,
    (-52*beta_31^2 + 468*beta_31 - 936)*alpha_31 + 26*beta_31^2 - 130*beta_31 + 572,
    0,
    -alpha_31 + 1/2*(beta_31^2 - 9*beta_31 + 12),
    0,
    0,
    0,
    0
  ],
  [
    1/4*(6617115607543764024267*beta_31^2 - 37709832571849093268799*beta_31 + 28899533835641349709866)*alpha_31 + 1958654868349556327472*beta_31^2 - 11161916061440579203356*beta_31 + 8574866616979608164964,
    (610424269343644450311*beta_31^2 - 3476574262560731865795*beta_31 + 2659048347921611063130)*alpha_31 + 413361975117539328912*beta_31^2 - 2353430504024343007200*beta_31 + 1809191663358485923728,
    (131955099294370372515*beta_31^2 - 751055987108451552354*beta_31 + 574315071249565476459)*alpha_31 + 1/2*(211426206698117645181*beta_31^2 - 1205451839499242183415*beta_31 + 929530162520984755152),
    (72987474815763031692*beta_31^2 - 415943760255231354876*beta_31 + 319223836111006114632)*alpha_31 - 99658290188156039109*beta_31^2 + 567201155701452040665*beta_31 - 432750949821878385294,
    1/4*(105710291398054497861*beta_31^2 - 603000853167986033409*beta_31 + 463204988889364558854)*alpha_31 + 1/2*(-155349154199537195679*beta_31^2 + 885009648748652008155*beta_31 - 678370330617061729482),
    (7786546818426902790*beta_31^2 - 44493252990596442594*beta_31 + 34415016725058412752)*alpha_31 - 22697577162900888660*beta_31^2 + 129269012323446160056*beta_31 - 98937868899405617460,
    1/4*(10806910577986417209*beta_31^2 - 61714575772704086517*beta_31 + 47763449044420370958)*alpha_31 + 1/2*(-14935243177307249883*beta_31^2 + 85102030000656475515*beta_31 - 65097851851638745614),
    1/2*(1224273082270067379*beta_31^2 - 6992663299836008247*beta_31 + 5430822979472569962)*alpha_31 - 1631446426834274277*beta_31^2 + 9302345006050631169*beta_31 - 7122008941505290854,
    1/4*(540153679031713605*beta_31^2 - 3090784636827018321*beta_31 + 2422648430152634358)*alpha_31 + 1/2*(-574125826969116165*beta_31^2 + 3270363769202571201*beta_31 - 2496560583539464326),
    (28943409348045468*beta_31^2 - 165449598009874524*beta_31 + 129270819685679064)*alpha_31 - 57951102685733280*beta_31^2 + 330047697828240720*beta_31 - 252214343173434960,
    1/4*(14908336074917721*beta_31^2 - 85554942554954097*beta_31 + 67891016786721570)*alpha_31 - 5394337423906986*beta_31^2 + 30728979333308241*beta_31 - 23591376866550537,
    (816204548910681*beta_31^2 - 4693513426243533*beta_31 + 3718099196733942)*alpha_31 - 1003603035329622*beta_31^2 + 5696053354646550*beta_31 - 4353978063398364,
    1/2*(146087623252863*beta_31^2 - 837992309560299*beta_31 + 656184316287258)*alpha_31 - 57734469692829*beta_31^2 + 330528273350949*beta_31 - 263678419192986,
    (11981148816150*beta_31^2 - 68786639192502*beta_31 + 55252225887228)*alpha_31 - 2682911427840*beta_31^2 + 16766409902472*beta_31 - 15160779720216,
    1/2*(2633652060237*beta_31^2 - 14883035614353*beta_31 + 11148703065198)*alpha_31 - 270208587339*beta_31^2 + 1710106923915*beta_31 - 1578368985678,
    1/2*(119863691001*beta_31^2 - 645970528773*beta_31 + 452764818558)*alpha_31 + 193062775698*beta_31^2 - 1070075376018*beta_31 + 729988233588,
    (18425442249*beta_31^2 - 103301892297*beta_31 + 76156469946)*alpha_31 + 16604361855*beta_31^2 - 94176323703*beta_31 + 68696172414,
    (-132812946*beta_31^2 + 708255378*beta_31 - 1763713908)*alpha_31 + 3091013352*beta_31^2 - 18409726152*beta_31 + 13997431728,
    1/2*(301275315*beta_31^2 - 1800725823*beta_31 + 1347447042)*alpha_31 + 536367177*beta_31^2 - 3126555801*beta_31 + 2315012778,
    1/2*(-4791231*beta_31^2 + 27655155*beta_31 - 17276274)*alpha_31 + 10261917*beta_31^2 - 58321593*beta_31 + 76876182,
    1/4*(133713*beta_31^2 - 458685*beta_31 + 4513806)*alpha_31 + 1/2*(10205991*beta_31^2 - 54668547*beta_31 + 41791482),
    (13797*beta_31^2 - 134757*beta_31 + 370386)*alpha_31 + 54216*beta_31^2 - 417204*beta_31 + 692820,
    1/4*(-2997*beta_31^2 - 44631*beta_31 + 348786)*alpha_31 + 1/2*(70065*beta_31^2 - 427869*beta_31 + 418446),
    1/2*(81*beta_31^2 - 621*beta_31 + 1566)*alpha_31 + 81*beta_31^2 - 405*beta_31 + 918,
    1/4*(135*beta_31^2 - 1755*beta_31 + 5346)*alpha_31 + 1/2*(189*beta_31^2 - 1161*beta_31 + 1350),
    0,
    1/4*(beta_31^2 - 9*beta_31 + 14)*alpha_31 + 1/2*(beta_31^2 - 7*beta_31 + 2),
    0,
    0,
    0
  ],
  [
    (55762759372652646522726*beta_31^2 - 318027904526199672282702*beta_31 + 244601878749299652200564)*alpha_31 + 54830356271630941788640*beta_31^2 - 312670395012856766210752*beta_31 + 240419734329469234329440,
    (17623187976387727035449*beta_31^2 - 100504202528229510071509*beta_31 + 77294205035625823243950)*alpha_31 + 21285364480770296336192*beta_31^2 - 121359166083088410806112*beta_31 + 93269463383621454050016,
    (2973968148086198038804*beta_31^2 - 16947302150565631400388*beta_31 + 12996954132488232578392)*alpha_31 + 14452418427870727281656*beta_31^2 - 82402110960024278537240*beta_31 + 63312188099621960827664,
    1/4*(4113574107041727736933*beta_31^2 - 23443572970204473561153*beta_31 + 17988786488213406323878)*alpha_31 + 4707313964844675792363*beta_31^2 - 26840764649242640546919*beta_31 + 20622336652631564011266,
    (71445902604837511912*beta_31^2 - 406168735731884132168*beta_31 + 306446472947480720176)*alpha_31 + 937872397931190618344*beta_31^2 - 5348379186284584993928*beta_31 + 4107851954554017093872,
    (-5398358890516940530*beta_31^2 + 31369636712750568274*beta_31 - 27229497297306845268)*alpha_31 + 335110231463850725512*beta_31^2 - 1911053663712236298752*beta_31 + 1467531937902713213496,
    (2043304913728563500*beta_31^2 - 11535990168194971324*beta_31 + 8303814847671764968)*alpha_31 + 33524518638716851432*beta_31^2 - 191130904827541714632*beta_31 + 146729921072115701680,
    (-782250819878556770*beta_31^2 + 4516605411411710386*beta_31 - 3698656536128863876)*alpha_31 + 7648848161292425206*beta_31^2 - 43597042834334171014*beta_31 + 33528206437194423948,
    (124428596467773556*beta_31^2 - 698291202914117988*beta_31 + 496811042130083800)*alpha_31 + 619116783868594984*beta_31^2 - 3529240768202089640*beta_31 + 2720049257627420432,
    (45888557450472226*beta_31^2 - 260048325311005266*beta_31 + 197899680870686116)*alpha_31 - 68925020253134024*beta_31^2 + 391700040608879520*beta_31 - 291696665379066584,
    (11332158265990072*beta_31^2 - 64491573850919096*beta_31 + 49285287867069744)*alpha_31 - 6810672472417744*beta_31^2 + 38219981785456016*beta_31 - 27012728790967136,
    1/2*(6786550221193883*beta_31^2 - 39016495477703639*beta_31 + 30787085443183650)*alpha_31 - 6478210032914116*beta_31^2 + 36666228657597854*beta_31 - 27665472778314966,
    (533872271953496*beta_31^2 - 3082609420323384*beta_31 + 2491942597518864)*alpha_31 - 528259780093248*beta_31^2 + 2966041239087136*beta_31 - 2150659329272608,
    (88826907031692*beta_31^2 - 513514621383900*beta_31 + 421048942386664)*alpha_31 - 131233286351296*beta_31^2 + 748087013787056*beta_31 - 561185172254800,
    (12001451055272*beta_31^2 - 69802142806760*beta_31 + 59810743762000)*alpha_31 - 7810358124016*beta_31^2 + 44814822054576*beta_31 - 32750382256032,
    1/2*(2527993041371*beta_31^2 - 14785806355215*beta_31 + 13565701064202)*alpha_31 - 1098798240092*beta_31^2 + 6350307362980*beta_31 - 4719947613808,
    (140422476180*beta_31^2 - 830389791812*beta_31 + 775891155032)*alpha_31 - 246522976*beta_31^2 + 7272201216*beta_31 - 41954982048,
    (11755158814*beta_31^2 - 75716090870*beta_31 + 87323260276)*alpha_31 - 929827864*beta_31^2 + 1606998120*beta_31 - 6316221408,
    (966113372*beta_31^2 - 6176767884*beta_31 + 6824380584)*alpha_31 + 1037797768*beta_31^2 - 5770164008*beta_31 + 2571149616,
    (75444894*beta_31^2 - 555528414*beta_31 + 918830892)*alpha_31 - 140147427*beta_31^2 + 911808359*beta_31 - 990196298,
    (3301676*beta_31^2 - 24143420*beta_31 + 37926504)*alpha_31 + 8441160*beta_31^2 - 34790280*beta_31 - 11718000,
    (968982*beta_31^2 - 7262486*beta_31 + 11895324)*alpha_31 - 2616712*beta_31^2 + 15988000*beta_31 - 19591320,
    (-16492*beta_31^2 + 113820*beta_31 + 18872)*alpha_31 + 22456*beta_31^2 + 2856*beta_31 - 286832,
    (5838*beta_31^2 - 35462*beta_31 + 54516)*alpha_31 - 30814*beta_31^2 + 229502*beta_31 - 312396,
    (84*beta_31^2 - 868*beta_31 + 1400)*alpha_31 + 168*beta_31^2 - 1288*beta_31 + 560,
    (14*beta_31^2 - 14*beta_31 - 308)*alpha_31 + 56*beta_31 - 1064,
    0,
    1/2*(beta_31 - 6)*alpha_31 + 1/2*(-beta_31^2 + 8*beta_31 - 12),
    0,
    0
  ],
  [
    1/4*(280406327475911210167201*beta_31^2 - 1599792784887475316275409*beta_31 + 1231771974244748286978490)*alpha_31 + 16426002189285313277180*beta_31^2 - 93549551149948966433836*beta_31 + 71510728957285524038376,
    (11766055414761923441939*beta_31^2 - 67145998566829615039323*beta_31 + 51780579916845115565750)*alpha_31 + 54011960660373290232293*beta_31^2 - 307856782675559671952201*beta_31 + 236307496542963606420158,
    1/4*(-13264917632126705615827*beta_31^2 + 75834597541707696572231*beta_31 - 58653454463726867895674)*alpha_31 + 1/2*(102415421219056900890615*beta_31^2 - 583859319286675364428223*beta_31 + 448535079898023007583646),
    1/2*(-8368401257809836623701*beta_31^2 + 47793079868711371016289*beta_31 - 36931754869614947050134)*alpha_31 + 25834018989944096888016*beta_31^2 - 147275391091747752378528*beta_31 + 113082399016617233482384,
    1/4*(-10488214303302851593819*beta_31^2 + 59846837322926673811651*beta_31 - 46153849254709105027302)*alpha_31 + 1/2*(19250515376178062745729*beta_31^2 - 109769054141615527851445*beta_31 + 84309757496819461880262),
    (-858114380689954758319*beta_31^2 + 4897808520309319540383*beta_31 - 3786205367294026183878)*alpha_31 + 2845885629671655353756*beta_31^2 - 16228956729527911161784*beta_31 + 12464120994726783432108,
    1/2*(-526388131745327488339*beta_31^2 + 3004692130875406978023*beta_31 - 2323362805159478472666)*alpha_31 + 647303864030793461241*beta_31^2 - 3690438647491086454361*beta_31 + 2832562835575605694138,
    (-62950659632018822483*beta_31^2 + 359366322164383949863*beta_31 - 277977657507308926106)*alpha_31 + 137256199421832389932*beta_31^2 - 782533488588870968468*beta_31 + 601171061193156949232,
    1/2*(-24651300239399838315*beta_31^2 + 140872556548348964307*beta_31 - 109388586785414556294)*alpha_31 + 19967555103996959056*beta_31^2 - 113818861784339878410*beta_31 + 87436027272397313134,
    1/2*(-5090535089369958103*beta_31^2 + 29089037772378972899*beta_31 - 22527290796496864362)*alpha_31 + 3271344262478173897*beta_31^2 - 18642548386094778257*beta_31 + 14335946980840112786,
    1/4*(-1271361588357147219*beta_31^2 + 7264728878663977295*beta_31 - 5634181523683686290)*alpha_31 + 1/2*(498821835648116541*beta_31^2 - 2853383970048327821*beta_31 + 2226835346398067890),
    (-60770638398976248*beta_31^2 + 346780935057547224*beta_31 - 268653359121012048)*alpha_31 + 14801237842050592*beta_31^2 - 86167806943976048*beta_31 + 68812618806615856,
    1/4*(-23033623025992685*beta_31^2 + 130676538483151765*beta_31 - 98720073188597786)*alpha_31 - 1053495769325008*beta_31^2 + 5681175893134009*beta_31 - 3567143870786603,
    (-715589211473838*beta_31^2 + 4052406918474182*beta_31 - 3061434189671124)*alpha_31 - 1384630942045468*beta_31^2 + 7857802496257500*beta_31 - 5875140674406872,
    (-100081864969943*beta_31^2 + 565481733913927*beta_31 - 412747082325206)*alpha_31 - 137414170186400*beta_31^2 + 786460246712988*beta_31 - 599603365073652,
    1/2*(-2033187910985*beta_31^2 + 10937320909317*beta_31 + 977225448018)*alpha_31 - 38043096651696*beta_31^2 + 218032945991072*beta_31 - 165145753893808,
    1/2*(-2571667562577*beta_31^2 + 14675148313493*beta_31 - 10720357037334)*alpha_31 - 4816148786668*beta_31^2 + 27614399373972*beta_31 - 21450717222960,
    1/2*(127955090065*beta_31^2 - 769175734365*beta_31 + 697675485614)*alpha_31 - 407644881711*beta_31^2 + 2307491124659*beta_31 - 1863771095490,
    1/4*(-15014556193*beta_31^2 + 82278962893*beta_31 - 65892619758)*alpha_31 + 1/2*(-186712924735*beta_31^2 + 1059022378363*beta_31 - 824882986506),
    (413938257*beta_31^2 - 2062711797*beta_31 - 51602890)*alpha_31 - 3068966412*beta_31^2 + 18462698156*beta_31 - 17446420184,
    1/4*(317311069*beta_31^2 - 1578605053*beta_31 + 29011426)*alpha_31 - 1054663590*beta_31^2 + 6079254253*beta_31 - 4851676481,
    (1703663*beta_31^2 - 4497639*beta_31 - 18285602)*alpha_31 - 18783300*beta_31^2 + 109410272*beta_31 - 107929532,
    1/2*(1209967*beta_31^2 - 2292131*beta_31 - 15828142)*alpha_31 - 6619047*beta_31^2 + 37698347*beta_31 - 29024882,
    (29551*beta_31^2 - 197635*beta_31 + 256882)*alpha_31 - 99876*beta_31^2 + 664332*beta_31 - 643104,
    1/2*(5365*beta_31^2 - 3973*beta_31 - 92510)*alpha_31 - 28913*beta_31^2 + 162429*beta_31 - 59566,
    1/2*(29*beta_31^2 - 145*beta_31 + 1566)*alpha_31 + 29*beta_31^2 + 203*beta_31 - 1334,
    1/4*(29*beta_31^2 - 377*beta_31 + 2262)*alpha_31 + 1/2*(-29*beta_31^2 - 87*beta_31 + 986),
    0,
    1/4*(beta_31^2 - 9*beta_31 + 14)*alpha_31 + 1/2*(beta_31^2 - 7*beta_31 + 2),
    0
  ],
  [
    (-1698206314199968428645645*beta_31^2 + 9684498694039326396986745*beta_31 - 7448063173909560411812070)*alpha_31 - 7419242204632236131693610*beta_31^2 + 42310948413181151098636050*beta_31 - 32535175310714144690513820,
    1/2*(-1116110354307394435571955*beta_31^2 + 6364602204143174800753815*beta_31 - 4893352438842718875237450)*alpha_31 + 1/2*(-4954708353448487015736255*beta_31^2 + 28256138212678403061011475*beta_31 - 21726052810752899220453330),
    (-23202972648972533368105*beta_31^2 + 132130670030852992699165*beta_31 - 100357410818571820530070)*alpha_31 - 1061451947412884096622790*beta_31^2 + 6053503828018495019093990*beta_31 - 4654106953389485686294620,
    1/2*(-37413072319842234398625*beta_31^2 + 213376518038213393172525*beta_31 - 163573112704274052843150)*alpha_31 - 322949472625147408382145*beta_31^2 + 1841838902146042629808845*beta_31 - 1416155482616403541873230,
    (-4156167175146716066226*beta_31^2 + 23677293394935340175514*beta_31 - 18081369934140062128620)*alpha_31 - 41464459131621308316564*beta_31^2 + 236459351958096606612468*beta_31 - 181842976721231149087848,
    1/4*(573261687522971335935*beta_31^2 - 3340816366296418895975*beta_31 + 2813873990958099545550)*alpha_31 - 14141675587892014751825*beta_31^2 + 80635495906455507180400*beta_31 - 62008172283181176374935,
    (-742409378856800951730*beta_31^2 + 4231976458010101005450*beta_31 - 3252234156623297447100)*alpha_31 - 288203429184225054780*beta_31^2 + 1644222632079756904140*beta_31 - 1275319292869953300360,
    (-136483715771726937105*beta_31^2 + 777655146032134194045*beta_31 - 597165950985326751630)*alpha_31 + 17659301363284804740*beta_31^2 - 99391399795723638420*beta_31 + 70701097304473676760,
    (-49851220849555952585*beta_31^2 + 284477629039369795765*beta_31 - 219304992376055275070)*alpha_31 + 32977512626584939410*beta_31^2 - 187575241440667340970*beta_31 + 142950147785783646780,
    1/4*(-52997178217866351273*beta_31^2 + 302891141422301239389*beta_31 - 234666382646367525846)*alpha_31 + 1/2*(34402173443607696411*beta_31^2 - 195721600395705298491*beta_31 + 149497012815301007118),
    (-2149084367788356045*beta_31^2 + 12286577298779935185*beta_31 - 9550795102466075310)*alpha_31 + 1557291431008329390*beta_31^2 - 8854766576968660830*beta_31 + 6717220175013343260,
    1/2*(-986317533514598205*beta_31^2 + 5640797683067429305*beta_31 - 4407074642020848630)*alpha_31 + 459670974718634165*beta_31^2 - 2623936510675531065*beta_31 + 2004368469007505470,
    (-63782503331833740*beta_31^2 + 365438455205561340*beta_31 - 289028513585253960)*alpha_31 + 24155262688432200*beta_31^2 - 137926015347119880*beta_31 + 103268672628621840,
    1/4*(-37949477680405575*beta_31^2 + 217457114616881955*beta_31 - 173349865105229370)*alpha_31 + 1/2*(5027518604190105*beta_31^2 - 28847383433491305*beta_31 + 22213977959497290),
    (-1213951482558388*beta_31^2 + 6999630060474644*beta_31 - 5707700761402536)*alpha_31 - 355422401285616*beta_31^2 + 2039040936182368*beta_31 - 1549095236916656,
    1/2*(-206324720768595*beta_31^2 + 1212691260037575*beta_31 - 1041973471395450)*alpha_31 - 76275954980190*beta_31^2 + 442782256917270*beta_31 - 326174288272020,
    (-13638084333195*beta_31^2 + 80272127686815*beta_31 - 69712631768970)*alpha_31 - 20275483193730*beta_31^2 + 115250393136570*beta_31 - 83653442692860,
    1/4*(-2742361218375*beta_31^2 + 17156383093595*beta_31 - 19294105893730)*alpha_31 + 1/2*(-1011375706095*beta_31^2 + 4981763139955*beta_31 - 2151764012610),
    (-66230975475*beta_31^2 + 405102219255*beta_31 - 425722022250)*alpha_31 - 349870601370*beta_31^2 + 1920202370370*beta_31 - 1258654944060,
    1/2*(-16250010135*beta_31^2 + 106536972027*beta_31 - 143512246002)*alpha_31 + 22762119651*beta_31^2 - 137169524751*beta_31 + 137471327682,
    (299230970*beta_31^2 - 1824109490*beta_31 + 745578540)*alpha_31 - 3297935260*beta_31^2 + 17383549020*beta_31 - 8744702680,
    1/4*(-510991965*beta_31^2 + 3062942805*beta_31 - 3098453610)*alpha_31 + 503090580*beta_31^2 - 3191714115*beta_31 + 3499561605,
    (2981130*beta_31^2 - 13556850*beta_31 + 9294300)*alpha_31 - 18731460*beta_31^2 + 102483060*beta_31 - 28601400,
    (-630245*beta_31^2 + 1654865*beta_31 + 6020010)*alpha_31 + 3482660*beta_31^2 - 23425820*beta_31 + 36652880,
    (22215*beta_31^2 - 149115*beta_31 + 186690)*alpha_31 - 4590*beta_31^2 - 69450*beta_31 + 401820,
    1/4*(4515*beta_31^2 - 157935*beta_31 + 749730)*alpha_31 + 1/2*(47955*beta_31^2 - 348315*beta_31 + 569910),
    (15*beta_31^2 - 195*beta_31 + 1170)*alpha_31 - 30*beta_31^2 - 90*beta_31 + 1020,
    1/2*(75*beta_31^2 - 975*beta_31 + 2970)*alpha_31 + 105*beta_31^2 - 645*beta_31 + 750,
    0,
    1/4*(beta_31^2 - 9*beta_31 + 14)*alpha_31 + 1/2*(beta_31^2 - 7*beta_31 + 2)
  ]
]
);

// Section ASSERTIONS //////////////////////////////////////////////////////////

assert (Evaluate(f_31,x_1) - Evaluate(g_31,x_2)) eq A_31*B_31;
sigmaM_30 := Matrix(30,30,[sigma(M_30[i][j]): i, j in [1..30]]);
assert M_30*sigmaM_30 eq 8*IdentityMatrix(k,30);


// End of File degree-31.m /////////////////////////////////////////////////////
